<?php
// admin/manage-admin-permissions.php - Owner Only Access
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../helpers/AuthHelper.php';
require_once __DIR__ . '/../helpers/RoleHelper.php';

// Require owner access only
AuthHelper::requireOwner($pdo);

$error = '';
$success = '';
$organizationId = $_SESSION['organization_id'];

// Handle permission updates
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'] ?? '';
    $userId = filter_var($_POST['user_id'] ?? null, FILTER_VALIDATE_INT);
    $grantedBy = $_SESSION['user_id'];
    
    if ($userId && $userId != $_SESSION['user_id']) {
        try {
            // Get target user info
            $stmt = $pdo->prepare("SELECT role, first_name, last_name FROM whsale_inventory_pro_users WHERE id = ? AND organization_id = ?");
            $stmt->execute([$userId, $organizationId]);
            $targetUser = $stmt->fetch();
            
            if (!$targetUser) {
                $error = "User not found.";
            } elseif ($targetUser['role'] === 'owner') {
                $error = "Cannot modify owner permissions.";
            } else {
                switch ($action) {
                    case 'apply_template':
                        $template = $_POST['template'] ?? '';
                        if (RoleHelper::applyPermissionTemplate($userId, $template, $grantedBy)) {
                            
                            // Refresh session cache if this user is currently logged in
                            if ($userId == $_SESSION['user_id']) {
                                RoleHelper::refreshUserPermissions($userId);
                            }
                            
                            $success = "Permission template '{$template}' applied successfully to {$targetUser['first_name']} {$targetUser['last_name']}.";
                        } else {
                            $error = "Failed to apply permission template.";
                        }
                        break;
                        
                    case 'update_permissions':
                        $selectedPermissions = $_POST['permissions'] ?? [];
                        
                        // Clear existing permissions
                        $stmt = $pdo->prepare("DELETE FROM whsale_inventory_pro_user_permissions WHERE user_id = ?");
                        $stmt->execute([$userId]);
                        
                        // Grant selected permissions
                        foreach ($selectedPermissions as $permission) {
                            RoleHelper::grantPermission($userId, $permission, $grantedBy);
                        }
                        
                        // Refresh session cache if this user is currently logged in
                        if ($userId == $_SESSION['user_id']) {
                            RoleHelper::refreshUserPermissions($userId);
                        }
                        
                        $success = "Permissions updated successfully for {$targetUser['first_name']} {$targetUser['last_name']}.";
                        break;
                        
                    case 'remove_all_permissions':
                        $stmt = $pdo->prepare("DELETE FROM whsale_inventory_pro_user_permissions WHERE user_id = ?");
                        $stmt->execute([$userId]);
                        
                        // Refresh session cache if this user is currently logged in
                        if ($userId == $_SESSION['user_id']) {
                            RoleHelper::refreshUserPermissions($userId);
                        }
                        
                        $success = "All permissions removed from {$targetUser['first_name']} {$targetUser['last_name']}.";
                        break;
                        
                    default:
                        $error = "Invalid action.";
                }
            }
        } catch (Exception $e) {
            error_log("Permission management error: " . $e->getMessage());
            $error = "Failed to update permissions. Please try again.";
        }
    } else {
        $error = "Invalid user selection.";
    }
}

// Get all admin users in organization
$adminUsers = [];
try {
    $stmt = $pdo->prepare("
        SELECT u.*, 
               COUNT(p.permission_key) as permission_count
        FROM whsale_inventory_pro_users u
        LEFT JOIN whsale_inventory_pro_user_permissions p ON u.id = p.user_id
        WHERE u.organization_id = ? AND u.role = 'admin' AND u.account_status = 'active'
        GROUP BY u.id
        ORDER BY u.first_name ASC, u.last_name ASC
    ");
    $stmt->execute([$organizationId]);
    $adminUsers = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (Exception $e) {
    error_log("Error loading admin users: " . $e->getMessage());
    $error = "Failed to load admin users.";
}

// Get permission templates
$templates = RoleHelper::getPermissionTemplates();

// Get all permissions grouped by category
$permissionCategories = RoleHelper::getPermissionsByCategory();
?>

<?php include __DIR__ . '/../views/partials/head.php'; ?>

<div class="container mt-4 mb-5">
    <div class="d-flex flex-column flex-sm-row justify-content-between align-items-start align-items-sm-center mb-4 gap-3">
        <div>
            <h4>Manage Admin Permissions <?= RoleHelper::getRoleBadge() ?></h4>
            <p class="text-muted mb-0">Customize what each administrator can access and modify</p>
        </div>
        <a href="<?= BASE_URL ?>admin/manage-users" class="btn btn-outline-secondary">
            <i class="fas fa-users me-1"></i>Back to User Management
        </a>
    </div>

    <?php if ($error): ?>
        <div class="alert alert-danger">
            <i class="fas fa-exclamation-circle me-2"></i><?= htmlspecialchars($error) ?>
        </div>
    <?php endif; ?>

    <?php if ($success): ?>
        <div class="alert alert-success">
            <i class="fas fa-check-circle me-2"></i><?= htmlspecialchars($success) ?>
        </div>
    <?php endif; ?>

    <?php if (empty($adminUsers)): ?>
        <div class="card shadow-sm">
            <div class="card-body text-center py-5">
                <i class="fas fa-user-shield fa-3x text-muted mb-3"></i>
                <h5 class="text-muted">No Admin Users Found</h5>
                <p class="text-muted mb-3">You don't have any administrators in your organization yet.</p>
                <a href="<?= BASE_URL ?>admin/manage-users" class="btn btn-primary">
                    <i class="fas fa-user-plus me-1"></i>Promote Users to Admin
                </a>
            </div>
        </div>
    <?php else: ?>

        <!-- Permission Templates Quick Actions -->
        <div class="card shadow-sm mb-4">
            <div class="card-header bg-primary text-white">
                <h6 class="mb-0">
                    <i class="fas fa-magic me-2"></i>Quick Permission Templates
                </h6>
            </div>
            <div class="card-body">
                <p class="text-muted mb-3">Apply pre-configured permission sets to administrators:</p>
                <div class="row g-3">
                    <?php foreach ($templates as $template): ?>
                        <div class="col-md-6 col-lg-4">
                            <div class="border rounded p-3 h-100 template-card" data-template="<?= htmlspecialchars($template['template_name']) ?>">
                                <h6 class="fw-bold text-primary"><?= htmlspecialchars($template['template_name']) ?></h6>
                                <p class="small text-muted mb-2"><?= htmlspecialchars($template['description']) ?></p>
                                <div class="small">
                                    <strong>Includes:</strong> <?= count($template['permissions']) ?> permissions
                                    <br>
                                    <button class="btn btn-sm btn-outline-primary mt-2" onclick="showTemplateDetails('<?= htmlspecialchars($template['template_name']) ?>')">
                                        View Details
                                    </button>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        </div>

        <!-- Admin Users Management -->
        <div class="row g-4">
            <?php foreach ($adminUsers as $user): ?>
                <div class="col-12 col-lg-6">
                    <div class="card shadow-sm h-100">
                        <div class="card-header bg-light d-flex justify-content-between align-items-center">
                            <div>
                                <h6 class="mb-0"><?= htmlspecialchars($user['first_name'] . ' ' . $user['last_name']) ?></h6>
                                <small class="text-muted"><?= htmlspecialchars($user['email']) ?></small>
                            </div>
                            <div class="d-flex align-items-center gap-2">
                                <?= RoleHelper::getRoleBadge($user['role']) ?>
                                <span class="badge bg-info"><?= $user['permission_count'] ?> permissions</span>
                            </div>
                        </div>
                        <div class="card-body">
                            
                            <!-- Apply Template Section -->
                            <div class="mb-3">
                                <label class="form-label small fw-bold">Quick Apply Template:</label>
                                <form method="POST" class="d-flex gap-2">
                                    <input type="hidden" name="action" value="apply_template">
                                    <input type="hidden" name="user_id" value="<?= $user['id'] ?>">
                                    <select name="template" class="form-select form-select-sm" required>
                                        <option value="">Choose template...</option>
                                        <?php foreach ($templates as $template): ?>
                                            <option value="<?= htmlspecialchars($template['template_name']) ?>">
                                                <?= htmlspecialchars($template['template_name']) ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                    <button type="submit" class="btn btn-sm btn-primary" onclick="return confirm('This will replace all current permissions with the template. Continue?')">
                                        Apply
                                    </button>
                                </form>
                            </div>

                            <hr>

                            <!-- Custom Permissions Section -->
                            <div class="mb-3">
                                <div class="d-flex justify-content-between align-items-center mb-2">
                                    <label class="form-label small fw-bold mb-0">Custom Permissions:</label>
                                    <button class="btn btn-sm btn-outline-info" onclick="showPermissionModal(<?= $user['id'] ?>, '<?= htmlspecialchars($user['first_name'] . ' ' . $user['last_name']) ?>')">
                                        <i class="fas fa-edit me-1"></i>Customize
                                    </button>
                                </div>
                                
                                <!-- Current Permissions Summary -->
                                <div class="current-permissions" id="permissions-summary-<?= $user['id'] ?>">
                                    <?php
                                    $userPermissions = RoleHelper::getUserPermissions($user['id']);
                                    if (empty($userPermissions)):
                                    ?>
                                        <small class="text-muted">No custom permissions assigned</small>
                                    <?php else: ?>
                                        <div class="permission-tags">
                                            <?php 
                                            $permissionDetails = RoleHelper::getAllPermissions();
                                            $categoryCounts = [];
                                            foreach ($userPermissions as $permission) {
                                                if (isset($permissionDetails[$permission])) {
                                                    $category = $permissionDetails[$permission]['category'];
                                                    $categoryCounts[$category] = ($categoryCounts[$category] ?? 0) + 1;
                                                }
                                            }
                                            foreach ($categoryCounts as $category => $count):
                                            ?>
                                                <span class="badge bg-secondary me-1 mb-1"><?= $category ?>: <?= $count ?></span>
                                            <?php endforeach; ?>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            </div>

                            <!-- Danger Zone -->
                            <div class="border-top pt-3">
                                <form method="POST" onsubmit="return confirm('Remove ALL permissions from this admin? They will only have basic user access until new permissions are granted.');">
                                    <input type="hidden" name="action" value="remove_all_permissions">
                                    <input type="hidden" name="user_id" value="<?= $user['id'] ?>">
                                    <button type="submit" class="btn btn-sm btn-outline-danger">
                                        <i class="fas fa-trash me-1"></i>Remove All Permissions
                                    </button>
                                </form>
                            </div>
                        </div>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>

    <?php endif; ?>
</div>

<!-- Permission Customization Modal -->
<div class="modal fade" id="permissionModal" tabindex="-1">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Customize Permissions</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <form method="POST" id="permissionForm">
                <div class="modal-body">
                    <input type="hidden" name="action" value="update_permissions">
                    <input type="hidden" name="user_id" id="modalUserId">
                    
                    <div class="mb-3">
                        <h6 id="modalUserName" class="text-primary"></h6>
                        <p class="text-muted small">Select the specific permissions this administrator should have:</p>
                    </div>

                    <div id="permissionCategories">
                        <?php foreach ($permissionCategories as $categoryName => $permissions): ?>
                            <div class="card mb-3">
                                <div class="card-header bg-light">
                                    <div class="d-flex justify-content-between align-items-center">
                                        <h6 class="mb-0"><?= htmlspecialchars($categoryName) ?></h6>
                                        <div>
                                            <button type="button" class="btn btn-sm btn-outline-primary" onclick="selectAllInCategory('<?= $categoryName ?>', true)">All</button>
                                            <button type="button" class="btn btn-sm btn-outline-secondary" onclick="selectAllInCategory('<?= $categoryName ?>', false)">None</button>
                                        </div>
                                    </div>
                                </div>
                                <div class="card-body">
                                    <?php foreach ($permissions as $permissionKey => $permission): ?>
                                        <div class="form-check mb-2">
                                            <input class="form-check-input permission-checkbox" 
                                                   type="checkbox" 
                                                   name="permissions[]" 
                                                   value="<?= htmlspecialchars($permissionKey) ?>"
                                                   id="perm_<?= htmlspecialchars($permissionKey) ?>"
                                                   data-category="<?= htmlspecialchars($categoryName) ?>">
                                            <label class="form-check-label" for="perm_<?= htmlspecialchars($permissionKey) ?>">
                                                <strong><?= htmlspecialchars($permission['name']) ?></strong>
                                                <br><small class="text-muted"><?= htmlspecialchars($permission['description']) ?></small>
                                            </label>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    <button type="submit" class="btn btn-primary">Save Permissions</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Template Details Modal -->
<div class="modal fade" id="templateModal" tabindex="-1">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="templateModalTitle">Template Details</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <div class="modal-body" id="templateModalBody">
                <!-- Template details will be loaded here -->
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
            </div>
        </div>
    </div>
</div>

<script>
// Template data for JavaScript
const templates = <?= json_encode($templates) ?>;
const allPermissions = <?= json_encode(RoleHelper::getAllPermissions()) ?>;

function showPermissionModal(userId, userName) {
    document.getElementById('modalUserId').value = userId;
    document.getElementById('modalUserName').textContent = userName;
    
    // Clear all checkboxes
    document.querySelectorAll('.permission-checkbox').forEach(cb => cb.checked = false);
    
    // Load current user permissions
    fetch(`<?= BASE_URL ?>api/get-user-permissions?user_id=${userId}`)
        .then(response => response.json())
        .then(data => {
            if (data.success && data.permissions) {
                data.permissions.forEach(permission => {
                    const checkbox = document.getElementById(`perm_${permission}`);
                    if (checkbox) checkbox.checked = true;
                });
            }
        })
        .catch(error => console.error('Error loading permissions:', error));
    
    new bootstrap.Modal(document.getElementById('permissionModal')).show();
}

function selectAllInCategory(category, select) {
    document.querySelectorAll(`[data-category="${category}"]`).forEach(cb => {
        cb.checked = select;
    });
}

function showTemplateDetails(templateName) {
    const template = templates.find(t => t.template_name === templateName);
    if (!template) return;
    
    document.getElementById('templateModalTitle').textContent = template.template_name;
    
    let html = `<p>${template.description}</p><hr><h6>Included Permissions:</h6><ul class="list-unstyled">`;
    
    template.permissions.forEach(permission => {
        if (allPermissions[permission]) {
            html += `<li class="mb-1">
                <strong>${allPermissions[permission].name}</strong>
                <br><small class="text-muted">${allPermissions[permission].description}</small>
            </li>`;
        }
    });
    
    html += '</ul>';
    document.getElementById('templateModalBody').innerHTML = html;
    new bootstrap.Modal(document.getElementById('templateModal')).show();
}

// Auto-refresh permission summary after form submission
document.getElementById('permissionForm').addEventListener('submit', function() {
    setTimeout(() => {
        location.reload();
    }, 1000);
});
</script>

<style>
.template-card {
    cursor: pointer;
    transition: all 0.2s ease;
}

.template-card:hover {
    border-color: #0d6efd !important;
    background-color: #f8f9ff;
}

.permission-tags .badge {
    font-size: 0.75em;
}

.current-permissions {
    min-height: 40px;
}

@media (max-width: 768px) {
    .modal-lg {
        max-width: 95%;
    }
    
    .card-body {
        padding: 1rem;
    }
}
</style>

<?php include __DIR__ . '/../views/partials/footer.php'; ?>