<?php
// admin/manage-users.php - Owner Only Access
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../helpers/AuthHelper.php';
require_once __DIR__ . '/../helpers/InvitationHelper.php';
require_once __DIR__ . '/../helpers/RoleHelper.php';

// Require owner access only
AuthHelper::requirePermission('manage_employee_accounts');
$error = '';
$success = '';
$organizationId = $_SESSION['organization_id'];

// Handle user actions
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'] ?? '';
    $userId = filter_var($_POST['user_id'] ?? null, FILTER_VALIDATE_INT);
    
    if ($userId && $userId != $_SESSION['user_id']) {
        try {
            // Get target user's role for security check
            $stmt = $pdo->prepare("SELECT role FROM whsale_inventory_pro_users WHERE id = ? AND organization_id = ?");
            $stmt->execute([$userId, $organizationId]);
            $targetUser = $stmt->fetch();
            
            if (!$targetUser) {
                $error = "User not found.";
            } elseif ($targetUser['role'] === 'owner') {
                $error = "Owner accounts cannot be modified.";
            } else {
                switch ($action) {
                    case 'suspend':
                        $stmt = $pdo->prepare("
                            UPDATE whsale_inventory_pro_users 
                            SET account_status = 'suspended' 
                            WHERE id = ? AND organization_id = ? AND role != 'owner'
                        ");
                        $stmt->execute([$userId, $organizationId]);
                        if ($stmt->rowCount() > 0) {
                            $success = "User account suspended successfully.";
                        } else {
                            $error = "Cannot suspend this user.";
                        }
                        break;
                        
                    case 'activate':
                        $stmt = $pdo->prepare("
                            UPDATE whsale_inventory_pro_users 
                            SET account_status = 'active' 
                            WHERE id = ? AND organization_id = ?
                        ");
                        $stmt->execute([$userId, $organizationId]);
                        if ($stmt->rowCount() > 0) {
                            $success = "User account activated successfully.";
                        } else {
                            $error = "Cannot activate this user.";
                        }
                        break;
                        
                    case 'make_admin':
                        $stmt = $pdo->prepare("
                            UPDATE whsale_inventory_pro_users 
                            SET role = 'admin' 
                            WHERE id = ? AND organization_id = ? AND role = 'user'
                        ");
                        $stmt->execute([$userId, $organizationId]);
                        if ($stmt->rowCount() > 0) {
                            $success = "User promoted to administrator successfully.";
                        } else {
                            $error = "Unable to promote this user.";
                        }
                        break;
                        
                    case 'make_user':
                        $stmt = $pdo->prepare("
                            UPDATE whsale_inventory_pro_users 
                            SET role = 'user' 
                            WHERE id = ? AND organization_id = ? AND role = 'admin'
                        ");
                        $stmt->execute([$userId, $organizationId]);
                        if ($stmt->rowCount() > 0) {
                            $success = "User role changed to regular user successfully.";
                        } else {
                            $error = "Cannot change this user's role.";
                        }
                        break;
                        
                    default:
                        $error = "Invalid action.";
                }
            }
        } catch (Exception $e) {
            error_log("Error updating user: " . $e->getMessage());
            $error = "Failed to update user. Please try again.";
        }
    } elseif ($userId == $_SESSION['user_id']) {
        $error = "You cannot modify your own account from this page.";
    } else {
        $error = "Invalid user ID.";
    }
}

// Get organization users
$users = [];
try {
    $stmt = $pdo->prepare("
        SELECT u.*, 
               invited_by_user.first_name as invited_by_first_name,
               invited_by_user.last_name as invited_by_last_name
        FROM whsale_inventory_pro_users u
        LEFT JOIN whsale_inventory_pro_users invited_by_user ON u.invited_by = invited_by_user.id
        WHERE u.organization_id = ?
        ORDER BY 
            CASE u.role 
                WHEN 'owner' THEN 1 
                WHEN 'admin' THEN 2 
                WHEN 'user' THEN 3 
                ELSE 4 
            END,
            u.first_name ASC, u.last_name ASC
    ");
    $stmt->execute([$organizationId]);
    $users = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (Exception $e) {
    error_log("Error loading users: " . $e->getMessage());
    $error = "Failed to load users. Please refresh the page.";
}

// Get pending invitations
$pendingInvitations = [];
try {
    $stmt = $pdo->prepare("
        SELECT i.*, 
               u.first_name as invited_by_first_name, 
               u.last_name as invited_by_last_name
        FROM whsale_inventory_pro_invitations i
        LEFT JOIN whsale_inventory_pro_users u ON i.invited_by = u.id
        WHERE i.organization_id = ? AND i.status = 'pending' AND i.expires_at > NOW()
        ORDER BY i.invited_at DESC
    ");
    $stmt->execute([$organizationId]);
    $pendingInvitations = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (Exception $e) {
    error_log("Error fetching pending invitations: " . $e->getMessage());
}

$orgName = InvitationHelper::getOrganizationName($organizationId, $pdo);
?>

<?php include __DIR__ . '/../views/partials/head.php'; ?>

<div class="container mt-4 mb-5">
    <div class="d-flex flex-column flex-sm-row justify-content-between align-items-start align-items-sm-center mb-4 gap-3">
        <div>
            <h4>Manage Users <?= RoleHelper::getRoleBadge() ?></h4>
            <p class="text-muted mb-0"><?= htmlspecialchars($orgName) ?></p>
        </div>
        <a href="<?= BASE_URL ?>admin/invite-employee" class="btn btn-primary">
            <i class="fas fa-user-plus me-1"></i>Invite Employee
        </a>
    </div>

    <?php if ($error): ?>
        <div class="alert alert-danger">
            <i class="fas fa-exclamation-circle me-2"></i><?= htmlspecialchars($error) ?>
        </div>
    <?php endif; ?>

    <?php if ($success): ?>
        <div class="alert alert-success">
            <i class="fas fa-check-circle me-2"></i><?= htmlspecialchars($success) ?>
        </div>
    <?php endif; ?>

    <div class="row g-4">
        <!-- Active Users -->
        <div class="col-12 col-lg-8">
            <div class="card shadow-sm border-0">
                <div class="card-header bg-white">
                    <h6 class="mb-0">
                        <i class="fas fa-users me-2"></i>Organization Users
                        <span class="badge bg-primary ms-2"><?= count($users) ?></span>
                    </h6>
                </div>
                <div class="card-body p-0">
                    <?php if (empty($users)): ?>
                        <div class="text-center py-5">
                            <i class="fas fa-users fa-2x text-muted mb-3"></i>
                            <p class="text-muted">No users found</p>
                        </div>
                    <?php else: ?>
                        <!-- Desktop Table View -->
                        <div class="table-responsive d-none d-lg-block">
                            <table class="table table-hover mb-0">
                                <thead class="table-light">
                                    <tr>
                                        <th>User</th>
                                        <th>Role</th>
                                        <th>Status</th>
                                        <th>Joined</th>
                                        <th width="120">Actions</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($users as $user): ?>
                                        <tr class="<?= $user['id'] == $_SESSION['user_id'] ? 'table-info' : '' ?><?= $user['role'] === 'owner' ? ' table-warning' : '' ?>">
                                            <td>
                                                <div class="d-flex align-items-center">
                                                    <div class="avatar-circle me-3">
                                                        <?= strtoupper(substr($user['first_name'] ?? 'U', 0, 1) . substr($user['last_name'] ?? 'U', 0, 1)) ?>
                                                    </div>
                                                    <div>
                                                        <div class="fw-semibold">
                                                            <?= htmlspecialchars(trim($user['first_name'] . ' ' . $user['last_name'])) ?>
                                                            <?php if ($user['id'] == $_SESSION['user_id']): ?>
                                                                <span class="badge bg-secondary ms-1">You</span>
                                                            <?php endif; ?>
                                                        </div>
                                                        <small class="text-muted"><?= htmlspecialchars($user['email']) ?></small>
                                                    </div>
                                                </div>
                                            </td>
                                            <td>
                                                <?= RoleHelper::getRoleBadge($user['role']) ?>
                                                <?php if ($user['role'] === 'owner'): ?>
                                                    <br><small class="text-muted">Protected Account</small>
                                                <?php endif; ?>
                                            </td>
                                            <td>
                                                <?php
                                                $statusColors = [
                                                    'active' => 'success',
                                                    'pending' => 'warning',
                                                    'suspended' => 'danger'
                                                ];
                                                $statusColor = $statusColors[$user['account_status']] ?? 'secondary';
                                                ?>
                                                <span class="badge bg-<?= $statusColor ?>">
                                                    <?= ucfirst($user['account_status']) ?>
                                                </span>
                                            </td>
                                            <td>
                                                <small class="text-muted">
                                                    <?= $user['completed_setup_at'] ? date('M j, Y', strtotime($user['completed_setup_at'])) : 'N/A' ?>
                                                    <?php if ($user['invited_by_first_name']): ?>
                                                        <br><span class="text-muted">by <?= htmlspecialchars($user['invited_by_first_name']) ?></span>
                                                    <?php endif; ?>
                                                </small>
                                            </td>
                                            <td>
                                                <?php if ($user['id'] != $_SESSION['user_id'] && $user['role'] !== 'owner'): ?>
                                                    <div class="dropdown">
                                                        <button class="btn btn-sm btn-outline-secondary dropdown-toggle" 
                                                                type="button" data-bs-toggle="dropdown">
                                                            <i class="fas fa-cog"></i>
                                                        </button>
                                                        <ul class="dropdown-menu dropdown-menu-end">
                                                            <?php if ($user['account_status'] === 'active'): ?>
                                                                <li>
                                                                    <a class="dropdown-item" href="#" 
                                                                       onclick="updateUser(<?= $user['id'] ?>, 'suspend')">
                                                                        <i class="fas fa-pause me-2"></i>Suspend
                                                                    </a>
                                                                </li>
                                                            <?php else: ?>
                                                                <li>
                                                                    <a class="dropdown-item" href="#" 
                                                                       onclick="updateUser(<?= $user['id'] ?>, 'activate')">
                                                                        <i class="fas fa-play me-2"></i>Activate
                                                                    </a>
                                                                </li>
                                                            <?php endif; ?>
                                                            
                                                    
                                                        </ul>
                                                    </div>
                                                <?php elseif ($user['role'] === 'owner'): ?>
                                                    <small class="text-muted">Protected</small>
                                                <?php elseif ($user['id'] == $_SESSION['user_id']): ?>
                                                    <small class="text-muted">Your account</small>
                                                <?php endif; ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>

                        <!-- Mobile Card View -->
                        <div class="d-block d-lg-none">
                            <?php foreach ($users as $user): ?>
                                <div class="card mb-3 shadow-sm <?= $user['id'] == $_SESSION['user_id'] ? 'border-info' : '' ?><?= $user['role'] === 'owner' ? ' border-warning' : '' ?>">
                                    <div class="card-body">
                                        <div class="d-flex align-items-start justify-content-between mb-3">
                                            <div class="d-flex align-items-center flex-grow-1">
                                                <div class="avatar-circle me-3">
                                                    <?= strtoupper(substr($user['first_name'] ?? 'U', 0, 1) . substr($user['last_name'] ?? 'U', 0, 1)) ?>
                                                </div>
                                                <div class="flex-grow-1">
                                                    <h6 class="mb-1">
                                                        <?= htmlspecialchars(trim($user['first_name'] . ' ' . $user['last_name'])) ?>
                                                        <?php if ($user['id'] == $_SESSION['user_id']): ?>
                                                            <span class="badge bg-secondary ms-1">You</span>
                                                        <?php endif; ?>
                                                    </h6>
                                                    <p class="text-muted small mb-0"><?= htmlspecialchars($user['email']) ?></p>
                                                </div>
                                            </div>
                                            
                                            <?php if ($user['id'] != $_SESSION['user_id'] && $user['role'] !== 'owner'): ?>
                                                <div class="dropdown">
                                                    <button class="btn btn-sm btn-outline-secondary dropdown-toggle" 
                                                            type="button" data-bs-toggle="dropdown">
                                                        <i class="fas fa-cog"></i>
                                                    </button>
                                                    <ul class="dropdown-menu dropdown-menu-end">
                                                        <?php if ($user['account_status'] === 'active'): ?>
                                                            <li>
                                                                <a class="dropdown-item" href="#" 
                                                                   onclick="updateUser(<?= $user['id'] ?>, 'suspend')">
                                                                    <i class="fas fa-pause me-2"></i>Suspend
                                                                </a>
                                                            </li>
                                                        <?php else: ?>
                                                            <li>
                                                                <a class="dropdown-item" href="#" 
                                                                   onclick="updateUser(<?= $user['id'] ?>, 'activate')">
                                                                    <i class="fas fa-play me-2"></i>Activate
                                                                </a>
                                            </li>
                                                        <?php endif; ?>
                                                        

                                                    </ul>
                                                </div>
                                            <?php endif; ?>
                                        </div>
                                        
                                        <div class="row g-2">
                                            <div class="col-6">
                                                <strong class="small">Role:</strong>
                                                <br>
                                                <?= RoleHelper::getRoleBadge($user['role']) ?>
                                                <?php if ($user['role'] === 'owner'): ?>
                                                    <br><small class="text-muted">Protected</small>
                                                <?php endif; ?>
                                            </div>
                                            <div class="col-6">
                                                <strong class="small">Status:</strong>
                                                <br>
                                                <?php
                                                $statusColors = [
                                                    'active' => 'success',
                                                    'pending' => 'warning',
                                                    'suspended' => 'danger'
                                                ];
                                                $statusColor = $statusColors[$user['account_status']] ?? 'secondary';
                                                ?>
                                                <span class="badge bg-<?= $statusColor ?>">
                                                    <?= ucfirst($user['account_status']) ?>
                                                </span>
                                            </div>
                                        </div>
                                        
                                        <div class="mt-2">
                                            <strong class="small">Joined:</strong>
                                            <span class="text-muted small">
                                                <?= $user['completed_setup_at'] ? date('M j, Y', strtotime($user['completed_setup_at'])) : 'N/A' ?>
                                                <?php if ($user['invited_by_first_name']): ?>
                                                    (by <?= htmlspecialchars($user['invited_by_first_name']) ?>)
                                                <?php endif; ?>
                                            </span>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>

        <!-- Pending Invitations Sidebar -->
        <div class="col-12 col-lg-4">
            <div class="card shadow-sm border-0">
                <div class="card-header bg-white">
                    <h6 class="mb-0">
                        <i class="fas fa-clock me-2"></i>Pending Invitations
                        <span class="badge bg-warning ms-2"><?= count($pendingInvitations) ?></span>
                    </h6>
                </div>
                <div class="card-body">
                    <?php if (empty($pendingInvitations)): ?>
                        <div class="text-center text-muted py-3">
                            <i class="fas fa-inbox fa-2x mb-2"></i>
                            <p class="small mb-0">No pending invitations</p>
                        </div>
                    <?php else: ?>
                        <?php foreach ($pendingInvitations as $invitation): ?>
                            <div class="border rounded p-3 mb-3">
                                <div class="d-flex justify-content-between align-items-start">
                                    <div class="flex-grow-1 me-2">
                                        <h6 class="mb-1"><?= htmlspecialchars($invitation['email']) ?></h6>
                                        <?php if ($invitation['first_name'] || $invitation['last_name']): ?>
                                            <p class="text-muted small mb-1">
                                                <?= htmlspecialchars(trim($invitation['first_name'] . ' ' . $invitation['last_name'])) ?>
                                            </p>
                                        <?php endif; ?>
                                        <div class="small text-muted">
                                            <?= RoleHelper::getRoleBadge($invitation['role']) ?>
                                            <br>Expires <?= date('M j', strtotime($invitation['expires_at'])) ?>
                                        </div>
                                    </div>
                                    <div class="dropdown">
                                        <button class="btn btn-sm btn-outline-secondary dropdown-toggle" 
                                                type="button" data-bs-toggle="dropdown">
                                            <i class="fas fa-ellipsis-v"></i>
                                        </button>
                                        <ul class="dropdown-menu dropdown-menu-end">
                                            <li>
                                                <a class="dropdown-item" href="#" 
                                                   onclick="resendInvitation(<?= $invitation['id'] ?>)">
                                                    <i class="fas fa-redo me-2"></i>Resend
                                                </a>
                                            </li>
                                            <li>
                                                <a class="dropdown-item text-danger" href="#" 
                                                   onclick="cancelInvitation(<?= $invitation['id'] ?>)">
                                                    <i class="fas fa-times me-2"></i>Cancel
                                                </a>
                                            </li>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
.avatar-circle {
    width: 40px;
    height: 40px;
    border-radius: 50%;
    background: linear-gradient(135deg, #007bff, #0056b3);
    color: white;
    display: flex;
    align-items: center;
    justify-content: center;
    font-weight: bold;
    font-size: 14px;
}

.table-hover tbody tr:hover {
    background-color: rgba(0, 123, 255, 0.05);
}

.badge {
    font-size: 0.75em;
}

/* Owner highlighting */
.table-warning {
    background-color: rgba(255, 193, 7, 0.1) !important;
}

.border-warning {
    border-color: #ffc107 !important;
    border-width: 2px !important;
}

/* Mobile optimizations */
@media (max-width: 991.98px) {
    .avatar-circle {
        width: 35px;
        height: 35px;
        font-size: 13px;
    }
    
    .card-body {
        padding: 1rem;
    }
    
    .badge {
        font-size: 0.7em;
    }
}

@media (max-width: 767.98px) {
    .container {
        padding-left: 15px;
        padding-right: 15px;
    }
    
    .card-body {
        padding: 0.75rem;
    }
    
    .avatar-circle {
        width: 32px;
        height: 32px;
        font-size: 12px;
    }
    
    .dropdown-toggle {
        padding: 0.25rem 0.5rem;
    }
    
    h4 {
        font-size: 1.25rem;
    }
    
    h6 {
        font-size: 1rem;
    }
}

/* Improve touch targets on mobile */
@media (max-width: 767.98px) {
    .btn-sm {
        padding: 0.375rem 0.75rem;
    }
    
    .dropdown-item {
        padding: 0.5rem 1rem;
    }
}
</style>

<script>
function updateUser(userId, action) {
    let confirmMessage = '';
    switch(action) {
        case 'suspend':
            confirmMessage = 'Suspend this user account? They will not be able to log in.';
            break;
        case 'activate':
            confirmMessage = 'Activate this user account?';
            break;
        case 'make_admin':
            confirmMessage = 'Promote this user to administrator? They will have full access to manage users and organization settings.';
            break;
        case 'make_user':
            confirmMessage = 'Change this user to regular user role? They will lose administrator privileges.';
            break;
        default:
            return;
    }
    
    if (confirm(confirmMessage)) {
        const form = document.createElement('form');
        form.method = 'POST';
        form.style.display = 'none';
        
        const actionInput = document.createElement('input');
        actionInput.type = 'hidden';
        actionInput.name = 'action';
        actionInput.value = action;
        
        const userIdInput = document.createElement('input');
        userIdInput.type = 'hidden';
        userIdInput.name = 'user_id';
        userIdInput.value = userId;
        
        form.appendChild(actionInput);
        form.appendChild(userIdInput);
        document.body.appendChild(form);
        form.submit();
    }
}

function resendInvitation(invitationId) {
    if (confirm('Resend invitation email?')) {
        fetch('<?= BASE_URL ?>admin/resend-invitation', {
            method: 'POST',
            headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
            body: `invitation_id=${invitationId}`
        })
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                alert('Invitation resent successfully!');
            } else {
                alert('Failed to resend invitation: ' + data.message);
            }
        })
        .catch(error => {
            alert('Error: ' + error.message);
        });
    }
}

function cancelInvitation(invitationId) {
    if (confirm('Cancel this invitation? The user will no longer be able to use this invitation link.')) {
        fetch('<?= BASE_URL ?>admin/cancel-invitation', {
            method: 'POST',
            headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
            body: `invitation_id=${invitationId}`
        })
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                location.reload();
            } else {
                alert('Failed to cancel invitation: ' + data.message);
            }
        })
        .catch(error => {
            alert('Error: ' + error.message);
        });
    }
}
</script>

<?php include __DIR__ . '/../views/partials/footer.php'; ?>