<?php
// auth/complete-invitation.php - Fixed Version
require_once __DIR__ . '/../helpers/InvitationHelper.php';

$error = '';
$success = '';
$invitation = null;
$token = $_GET['token'] ?? '';
$debugInfo = [];

// Debug: Log the token being checked
$debugInfo['token_received'] = $token;
$debugInfo['token_length'] = strlen($token);

// Validate token
if (!$token) {
    $error = "Invalid invitation link - no token provided.";
    $debugInfo['error_reason'] = 'no_token';
} else {
    // Debug: Check what's in the database - FIXED SQL
    try {
        $stmt = $pdo->prepare("
            SELECT i.*, i.status, i.expires_at,
                   COALESCE(o.organization_slug, 'Your Organization') as organization_name,
                   NOW() as current_datetime
            FROM whsale_inventory_pro_invitations i
            LEFT JOIN whsale_inventory_pro_organizations o ON i.organization_id = o.id
            WHERE i.invitation_token = ?
        ");
        $stmt->execute([$token]);
        $debugInvitation = $stmt->fetch(PDO::FETCH_ASSOC);
        
        $debugInfo['db_lookup'] = $debugInvitation ? 'found' : 'not_found';
        
        if ($debugInvitation) {
            $debugInfo['invitation_status'] = $debugInvitation['status'];
            $debugInfo['expires_at'] = $debugInvitation['expires_at'];
            $debugInfo['current_datetime'] = $debugInvitation['current_datetime'];
            $debugInfo['is_expired'] = (strtotime($debugInvitation['expires_at']) < time());
            $debugInfo['time_until_expiry'] = strtotime($debugInvitation['expires_at']) - time();
            $debugInfo['organization_id'] = $debugInvitation['organization_id'];
            $debugInfo['email'] = $debugInvitation['email'];
        }
    } catch (Exception $e) {
        $debugInfo['db_error'] = $e->getMessage();
    }
    
    $invitation = InvitationHelper::validateInvitationToken($token, $pdo);
    
    if (!$invitation) {
        $error = "This invitation link is invalid, expired, or has already been used.";
        $debugInfo['validation_result'] = 'failed';
        
        // More specific error checking
        if (isset($debugInvitation) && $debugInvitation) {
            if ($debugInvitation['status'] !== 'pending') {
                $debugInfo['specific_error'] = 'status_not_pending';
                $debugInfo['actual_status'] = $debugInvitation['status'];
            } elseif (strtotime($debugInvitation['expires_at']) < time()) {
                $debugInfo['specific_error'] = 'expired';
            } else {
                $debugInfo['specific_error'] = 'unknown_validation_failure';
            }
        } else {
            $debugInfo['specific_error'] = 'token_not_found';
        }
    } else {
        $debugInfo['validation_result'] = 'success';
    }
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $invitation) {
    $firstName = trim($_POST['first_name'] ?? '');
    $lastName = trim($_POST['last_name'] ?? '');
    $password = $_POST['password'] ?? '';
    $confirmPassword = $_POST['confirm_password'] ?? '';
    
    // Validation
    if (!$firstName) {
        $error = "First name is required.";
    } elseif (!$lastName) {
        $error = "Last name is required.";
    } elseif (strlen($password) < 8) {
        $error = "Password must be at least 8 characters long.";
    } elseif ($password !== $confirmPassword) {
        $error = "Passwords do not match.";
    } else {
        try {
            $pdo->beginTransaction();
            
            // Create user account
            $hashedPassword = password_hash($password, PASSWORD_DEFAULT);
            
            $stmt = $pdo->prepare("
                INSERT INTO whsale_inventory_pro_users 
                (organization_id, email, first_name, last_name, password_hash, role, account_status, invited_by, invited_at, completed_setup_at) 
                VALUES (?, ?, ?, ?, ?, ?, 'active', ?, ?, NOW())
            ");
            $stmt->execute([
                $invitation['organization_id'],
                $invitation['email'],
                $firstName,
                $lastName,
                $hashedPassword,
                $invitation['role'],
                $invitation['invited_by'],
                $invitation['invited_at']
            ]);
            
            $userId = $pdo->lastInsertId();
            
            // Update invitation status
            $stmt = $pdo->prepare("
                UPDATE whsale_inventory_pro_invitations 
                SET status = 'accepted', accepted_at = NOW(), user_id = ? 
                WHERE id = ?
            ");
            $stmt->execute([$userId, $invitation['id']]);
            
            $pdo->commit();
            
            // Log them in
            session_start();
            $_SESSION['user_id'] = $userId;
            $_SESSION['organization_id'] = $invitation['organization_id'];
            $_SESSION['user_role'] = $invitation['role'];
            $_SESSION['username'] = $invitation['email']; // Add this for compatibility
            $_SESSION['first_name'] = $firstName;
            $_SESSION['last_name'] = $lastName;
            $_SESSION['success'] = "Welcome to " . htmlspecialchars($invitation['organization_name']) . "! Your account has been created successfully.";
            
            header("Location: " . BASE_URL . "dashboard");
            exit;
            
        } catch (Exception $e) {
            $pdo->rollback();
            $error = "Failed to create account: " . $e->getMessage();
            $debugInfo['account_creation_error'] = $e->getMessage();
        }
    }
}
?>

<?php include __DIR__ . '/../views/partials/head.php'; ?>

<div class="container">
    <div class="row justify-content-center">
        <div class="col-md-8 col-lg-6">
            
            <!-- Debug Information (only show if there's an error) -->
            <?php if ($error && isset($_GET['debug'])): ?>
            <div class="card mb-4 border-warning">
                <div class="card-header bg-warning text-dark">
                    <h6 class="mb-0">Debug Information</h6>
                </div>
                <div class="card-body">
                    <pre class="small"><?= htmlspecialchars(print_r($debugInfo, true)) ?></pre>
                    
                    <?php if (isset($debugInfo['specific_error']) && $debugInfo['specific_error'] === 'token_not_found'): ?>
                    <div class="alert alert-info mt-3">
                        <strong>Quick Fix:</strong> Try generating a new invitation or check if the email link was copied correctly.
                    </div>
                    <?php endif; ?>
                </div>
            </div>
            <?php endif; ?>
            
            <div class="card shadow-lg border-0 mt-5">
                <div class="card-header bg-primary text-white text-center py-4">
                    <h4 class="mb-0">
                        <i class="fas fa-user-check me-2"></i>Complete Your Account
                    </h4>
                    <?php if ($invitation): ?>
                        <p class="mb-0 mt-2 opacity-75">
                            Welcome to <?= htmlspecialchars($invitation['organization_name']) ?>
                        </p>
                    <?php endif; ?>
                </div>
                
                <div class="card-body p-4">
                    <?php if ($error): ?>
                        <div class="alert alert-danger">
                            <i class="fas fa-exclamation-circle me-2"></i><?= htmlspecialchars($error) ?>
                            <?php if (!isset($_GET['debug'])): ?>
                                <br><small class="mt-2">
                                    <a href="?token=<?= urlencode($token) ?>&debug=1">Click here for debug information</a>
                                </small>
                            <?php endif; ?>
                        </div>
                    <?php endif; ?>
                    
                    <?php if ($invitation): ?>
                        <div class="alert alert-info">
                            <i class="fas fa-info-circle me-2"></i>
                            You've been invited as a <strong><?= ucfirst($invitation['role']) ?></strong> to join 
                            <strong><?= htmlspecialchars($invitation['organization_name']) ?></strong>
                        </div>
                        
                        <form method="POST">
                            <div class="mb-3">
                                <label for="email" class="form-label">Email Address</label>
                                <input type="email" class="form-control" id="email" 
                                       value="<?= htmlspecialchars($invitation['email']) ?>" disabled>
                                <div class="form-text">This cannot be changed.</div>
                            </div>
                            
                            <div class="row">
                                <div class="col-md-6 mb-3">
                                    <label for="firstName" class="form-label">First Name <span class="text-danger">*</span></label>
                                    <input type="text" class="form-control" id="firstName" name="first_name" 
                                           value="<?= htmlspecialchars($invitation['first_name'] ?: ($_POST['first_name'] ?? '')) ?>" 
                                           required maxlength="100">
                                </div>
                                <div class="col-md-6 mb-3">
                                    <label for="lastName" class="form-label">Last Name <span class="text-danger">*</span></label>
                                    <input type="text" class="form-control" id="lastName" name="last_name" 
                                           value="<?= htmlspecialchars($invitation['last_name'] ?: ($_POST['last_name'] ?? '')) ?>" 
                                           required maxlength="100">
                                </div>
                            </div>
                            
                            <div class="mb-3">
                                <label for="password" class="form-label">Password <span class="text-danger">*</span></label>
                                <input type="password" class="form-control" id="password" name="password" required>
                                <div class="form-text">Must be at least 8 characters long.</div>
                            </div>
                            
                            <div class="mb-4">
                                <label for="confirmPassword" class="form-label">Confirm Password <span class="text-danger">*</span></label>
                                <input type="password" class="form-control" id="confirmPassword" name="confirm_password" required>
                            </div>
                            
                            <div class="d-grid">
                                <button type="submit" class="btn btn-primary btn-lg">
                                    <i class="fas fa-check me-1"></i>Complete Setup & Sign In
                                </button>
                            </div>
                        </form>
                        
                        <div class="text-center mt-4">
                            <small class="text-muted">
                                By completing your account, you agree to our terms of service and privacy policy.
                            </small>
                        </div>
                    <?php else: ?>
                        <div class="text-center py-4">
                            <i class="fas fa-exclamation-triangle fa-3x text-warning mb-3"></i>
                            <h5>Invalid Invitation</h5>
                            <p class="text-muted">This invitation link is invalid, expired, or has already been used.</p>
                            
                            <?php if (isset($debugInfo['specific_error'])): ?>
                                <div class="alert alert-info text-start">
                                    <strong>Reason:</strong>
                                    <?php
                                    switch($debugInfo['specific_error']) {
                                        case 'token_not_found':
                                            echo 'The invitation token was not found in the database. Please request a new invitation.';
                                            break;
                                        case 'status_not_pending':
                                            echo 'This invitation has already been used or cancelled. Status: ' . htmlspecialchars($debugInfo['actual_status'] ?? 'unknown');
                                            break;
                                        case 'expired':
                                            echo 'This invitation has expired. Please request a new invitation.';
                                            break;
                                        default:
                                            echo 'Unknown validation error. Please contact support.';
                                    }
                                    ?>
                                </div>
                            <?php endif; ?>
                            
                            <a href="<?= BASE_URL ?>login" class="btn btn-primary">
                                <i class="fas fa-sign-in-alt me-1"></i>Go to Login
                            </a>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
            
            <div class="text-center mt-3">
                <small class="text-muted">
                    Already have an account? <a href="<?= BASE_URL ?>login">Sign in here</a>
                </small>
            </div>
        </div>
    </div>
</div>

<script>
// Real-time password matching validation
document.addEventListener('DOMContentLoaded', function() {
    const password = document.getElementById('password');
    const confirmPassword = document.getElementById('confirmPassword');
    
    function validatePasswords() {
        if (confirmPassword.value && password.value !== confirmPassword.value) {
            confirmPassword.setCustomValidity('Passwords do not match');
            confirmPassword.classList.add('is-invalid');
        } else {
            confirmPassword.setCustomValidity('');
            confirmPassword.classList.remove('is-invalid');
        }
    }
    
    if (password && confirmPassword) {
        password.addEventListener('input', validatePasswords);
        confirmPassword.addEventListener('input', validatePasswords);
    }
});
</script>

<?php include __DIR__ . '/../views/partials/footer.php'; ?>