<?php
// helpers/AuthHelper.php - Updated with permission integration
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/RoleHelper.php';

class AuthHelper
{
    public static function isLoggedIn(): bool
    {
        return isset($_SESSION['user_id']);
    }
    
    public static function requireLogin()
{
    if (!self::isLoggedIn()) {
        header("Location: " . BASE_URL . "login");
        exit;
    }
    
    // Auto-refresh permissions if they're older than 5 minutes
    $lastRefresh = $_SESSION['permissions_last_refresh'] ?? 0;
    if (time() - $lastRefresh > 300) { // 5 minutes
        if (isset($_SESSION['user_id'])) {
            RoleHelper::refreshUserPermissions($_SESSION['user_id']);
            $_SESSION['permissions_last_refresh'] = time();
        }
    }
}
    
    public static function getUserId(): int
    {
        return $_SESSION['user_id'] ?? null;
    }
    
    public static function getUsername(): string
    {
        return $_SESSION['username'] ?? null;
    }
    
    /**
     * Updated setUserRole - now also loads permissions
     */
    public static function setUserRole($userId, $pdo)
    {
        try {
            $stmt = $pdo->prepare("
                SELECT role FROM whsale_inventory_pro_users 
                WHERE id = ? AND account_status = 'active'
            ");
            $stmt->execute([$userId]);
            $user = $stmt->fetch();
            $_SESSION['user_role'] = $user ? $user['role'] : 'user';
            
            // Load user permissions into session
            RoleHelper::loadUserPermissions($userId);
            
        } catch (Exception $e) {
            $_SESSION['user_role'] = 'user';
            $_SESSION['user_permissions'] = [];
        }
    }
    
    /**
     * Check if current user has admin privileges
     */
    public static function isCurrentUserAdmin($pdo): bool
    {
        if (!isset($_SESSION['user_id'])) {
            return false;
        }
        
        try {
            $stmt = $pdo->prepare("
                SELECT role FROM whsale_inventory_pro_users 
                WHERE id = ? AND account_status = 'active'
            ");
            $stmt->execute([$_SESSION['user_id']]);
            $user = $stmt->fetch();
            return $user && $user['role'] === 'admin';
        } catch (Exception $e) {
            return false;
        }
    }
    
    /**
     * Check if current user has owner privileges
     */
    public static function isCurrentUserOwner($pdo): bool
    {
        if (!isset($_SESSION['user_id'])) {
            return false;
        }
        
        try {
            $stmt = $pdo->prepare("
                SELECT role FROM whsale_inventory_pro_users 
                WHERE id = ? AND account_status = 'active'
            ");
            $stmt->execute([$_SESSION['user_id']]);
            $user = $stmt->fetch();
            return $user && $user['role'] === 'owner';
        } catch (Exception $e) {
            return false;
        }
    }
    
    /**
     * Check if user can access admin features (updated to use granular permissions)
     */
    public static function canAccessAdmin($pdo): bool
    {
        self::requireLogin();
        return RoleHelper::hasPermission('manage_employee_accounts') || 
               RoleHelper::hasPermission('invite_employees') ||
               self::isCurrentUserAdmin($pdo);
    }
    
    /**
     * Check if user can access owner features
     */
    public static function canAccessOwner($pdo): bool
    {
        self::requireLogin();
        return self::isCurrentUserOwner($pdo);
    }
    
    /**
     * Get current user's role from session
     */
    public static function getUserRole(): string
    {
        return $_SESSION['user_role'] ?? 'user';
    }
    
    /**
     * Check if current user has specific role
     */
    public static function hasRole($role): bool
    {
        return self::getUserRole() === $role;
    }
    
    /**
     * Check if current user has admin or owner privileges
     */
    public static function canManageOrganization($pdo): bool
    {
        return self::isCurrentUserAdmin($pdo) || self::isCurrentUserOwner($pdo);
    }
    
    /**
     * Require admin access - redirect if not admin (legacy compatibility)
     */
    public static function requireAdmin($pdo)
    {
        self::requireLogin();
        
        if (!self::isCurrentUserAdmin($pdo)) {
            $_SESSION['error'] = "Access denied. Administrator privileges required.";
            header("Location: " . BASE_URL . "dashboard");
            exit;
        }
    }
    
    /**
     * Require owner access - redirect if not owner
     */
    public static function requireOwner($pdo)
    {
        self::requireLogin();
        
        if (!self::isCurrentUserOwner($pdo)) {
            $_SESSION['error'] = "Access denied. Owner privileges required.";
            header("Location: " . BASE_URL . "dashboard");
            exit;
        }
    }
    
    /**
     * Require admin or owner access - redirect if neither (legacy compatibility)
     */
    public static function requireAdminOrOwner($pdo)
    {
        self::requireLogin();
        
        if (!self::canManageOrganization($pdo)) {
            $_SESSION['error'] = "Access denied. Administrator or Owner privileges required.";
            header("Location: " . BASE_URL . "dashboard");
            exit;
        }
    }
    
    /**
     * NEW: Require specific permission (recommended for new code)
     */
    public static function requirePermission($permission, $redirectUrl = null)
    {
        self::requireLogin();
        
        if (!RoleHelper::hasPermission($permission)) {
            $redirectUrl = $redirectUrl ?: BASE_URL . "dashboard";
            $_SESSION['error'] = "You don't have permission to access this feature.";
            $_SESSION['missing_permission'] = $permission;
            header("Location: " . $redirectUrl);
            exit;
        }
    }
    
    /**
     * NEW: Check permission for AJAX requests
     */
    public static function requirePermissionAjax($permission)
    {
        self::requireLogin();
        
        if (!RoleHelper::hasPermission($permission)) {
            http_response_code(403);
            echo json_encode([
                'success' => false,
                'error' => 'Permission denied',
                'missing_permission' => $permission
            ]);
            exit;
        }
    }
    
    /**
     * NEW: Check if user has any of the specified permissions
     */
    public static function hasAnyPermission($permissions)
    {
        foreach ($permissions as $permission) {
            if (RoleHelper::hasPermission($permission)) {
                return true;
            }
        }
        return false;
    }
    
    /**
     * NEW: Require any of the specified permissions
     */
    public static function requireAnyPermission($permissions, $redirectUrl = null)
    {
        self::requireLogin();
        
        if (!self::hasAnyPermission($permissions)) {
            $redirectUrl = $redirectUrl ?: BASE_URL . "dashboard";
            $_SESSION['error'] = "You don't have permission to access this feature.";
            $_SESSION['missing_permissions'] = $permissions;
            header("Location: " . $redirectUrl);
            exit;
        }
    }
    
    /**
     * NEW: Logout and clear all session data
     */
    public static function logout()
    {
        // Clear all session data
        $_SESSION = array();
        
        // Delete the session cookie
        if (ini_get("session.use_cookies")) {
            $params = session_get_cookie_params();
            setcookie(session_name(), '', time() - 42000,
                $params["path"], $params["domain"],
                $params["secure"], $params["httponly"]
            );
        }
        
        // Destroy the session
        session_destroy();
    }
}
?>