<?php
// helpers/RoleHelper.php
// Enhanced Role Helper class with Granular Permissions

class RoleHelper {
    
    /**
     * Define base role permissions (fallback for when no custom permissions exist)
     */
    const BASE_PERMISSIONS = [
        'owner' => [
            // Owners have ALL permissions by default
            'invite_employees' => true,
            'manage_employee_accounts' => true,
            'manage_admin_permissions' => true,
            'view_user_activity' => true,
            'add_inventory' => true,
            'edit_inventory' => true,
            'delete_inventory' => true,
            'view_all_inventory' => true,
            'manage_categories' => true,
            'create_receiving_logs' => true,
            'edit_receiving_logs' => true,
            'delete_receiving_logs' => true,
            'upload_receiving_photos' => true,
            'manage_receiving_photos' => true,
            'publish_to_storefront' => true,
            'edit_storefront_listings' => true,
            'remove_storefront_listings' => true,
            'manage_storefront_branding' => true,
            'view_organization_data' => true,
            'export_inventory_data' => true,
            'export_receiving_data' => true,
            'view_storefront_analytics' => true,
            'access_reports_dashboard' => true,
            'manage_customer_inquiries' => true,
            'manage_organization_settings' => true
        ],
        'admin' => [
            // Admins get permissions from database, fallback to these
            'view_all_inventory' => true,
            'add_inventory' => true,
            'edit_inventory' => true,
            'create_receiving_logs' => true,
            'edit_receiving_logs' => true
        ],
        'user' => [
            // Regular users have minimal permissions
            'add_inventory' => true,
            'edit_inventory' => true,
            'create_receiving_logs' => true,
            'view_organization_data' => false
        ]
    ];

    /**
     * Permission hierarchy - higher permissions include lower ones
     */
    const PERMISSION_HIERARCHY = [
        'delete_inventory' => ['edit_inventory', 'view_all_inventory'],
        'edit_inventory' => ['view_all_inventory'],
        'delete_receiving_logs' => ['edit_receiving_logs', 'create_receiving_logs'],
        'edit_receiving_logs' => ['create_receiving_logs'],
        'manage_receiving_photos' => ['upload_receiving_photos'],
        'remove_storefront_listings' => ['edit_storefront_listings', 'publish_to_storefront'],
        'edit_storefront_listings' => ['publish_to_storefront'],
        'manage_storefront_branding' => ['publish_to_storefront'],
        'manage_employee_accounts' => ['invite_employees'],
        'export_receiving_data' => ['view_all_inventory'],
        'export_inventory_data' => ['view_all_inventory'],
        'manage_payment_links' => ['category' => 'Storefront Management', 'name' => 'Manage Payment Links', 'description' => 'Add and edit payment links for online sales']
    ];

    /**
     * Check if user has specific permission
     */
    public static function hasPermission($permission, $userId = null) {
        global $pdo;
        
        $userId = $userId ?: ($_SESSION['user_id'] ?? null);
        $role = $_SESSION['user_role'] ?? 'user';
        
        // Owners always have all permissions
        if ($role === 'owner') {
            return true;
        }
        
        // Check cached permissions first
        if (isset($_SESSION['user_permissions'])) {
            $userPermissions = $_SESSION['user_permissions'];
            
            // Direct permission check
            if (in_array($permission, $userPermissions)) {
                return true;
            }
            
            // Check hierarchical permissions
            foreach (self::PERMISSION_HIERARCHY as $higherPerm => $includedPerms) {
                if (in_array($higherPerm, $userPermissions) && in_array($permission, $includedPerms)) {
                    return true;
                }
            }
            
            return false;
        }
        
        // If not cached, check database
        return self::checkPermissionInDatabase($userId, $permission);
    }
    
    /**
     * Check permission directly in database
     */
    private static function checkPermissionInDatabase($userId, $permission) {
        global $pdo;
        
        try {
            $stmt = $pdo->prepare("CALL CheckUserPermission(?, ?)");
            $stmt->execute([$userId, $permission]);
            $result = $stmt->fetch();
            $stmt->closeCursor();
            
            if ($result && $result['has_permission']) {
                return true;
            }
            
            // Check hierarchical permissions in database
            foreach (self::PERMISSION_HIERARCHY as $higherPerm => $includedPerms) {
                if (in_array($permission, $includedPerms)) {
                    $stmt = $pdo->prepare("CALL CheckUserPermission(?, ?)");
                    $stmt->execute([$userId, $higherPerm]);
                    $result = $stmt->fetch();
                    $stmt->closeCursor();
                    
                    if ($result && $result['has_permission']) {
                        return true;
                    }
                }
            }
            
            return false;
        } catch (Exception $e) {
            error_log("Permission check error: " . $e->getMessage());
            
            // Fallback to base permissions
            $role = $_SESSION['user_role'] ?? 'user';
            return self::BASE_PERMISSIONS[$role][$permission] ?? false;
        }
    }
    
    /**
     * Load and cache user permissions in session
     */
    public static function loadUserPermissions($userId) {
        global $pdo;
        
        try {
            $stmt = $pdo->prepare("
                SELECT permission_key 
                FROM whsale_inventory_pro_user_permissions 
                WHERE user_id = ? AND granted = TRUE
            ");
            $stmt->execute([$userId]);
            $permissions = $stmt->fetchAll(PDO::FETCH_COLUMN);
            $stmt->closeCursor();
            
            $_SESSION['user_permissions'] = $permissions;
            return $permissions;
        } catch (Exception $e) {
            error_log("Error loading user permissions: " . $e->getMessage());
            $_SESSION['user_permissions'] = [];
            return [];
        }
    }
    
    /**
     * Refresh user permissions (call when permissions are updated)
     */
    public static function refreshUserPermissions($userId = null) {
        $userId = $userId ?: ($_SESSION['user_id'] ?? null);
        unset($_SESSION['user_permissions']);
        return self::loadUserPermissions($userId);
    }
    
    /**
     * Check if current user is owner
     */
    public static function isOwner() {
        return ($_SESSION['user_role'] ?? 'user') === 'owner';
    }
    
    /**
     * Check if current user is admin or higher
     */
    public static function isAdminOrHigher() {
        $role = $_SESSION['user_role'] ?? 'user';
        return in_array($role, ['owner', 'admin']);
    }
    
    /**
     * Enhanced canModifyUser with permission checking
     */
    public static function canModifyUser($targetUserId, $targetUserRole, $pdo) {
        $currentUserId = $_SESSION['user_id'] ?? null;
        $currentUserRole = $_SESSION['user_role'] ?? 'user';
        
        // Users cannot modify themselves through admin panel
        if ($targetUserId == $currentUserId) {
            return false;
        }
        
        // Regular users cannot modify anyone
        if ($currentUserRole === 'user') {
            return false;
        }
        
        // Owners cannot be modified by anyone except themselves
        if ($targetUserRole === 'owner') {
            return false;
        }
        
        // Check specific permissions
        if ($currentUserRole === 'admin') {
            // Admins need proper permissions to modify users
            if ($targetUserRole === 'admin') {
                return self::hasPermission('manage_admin_permissions');
            } else {
                return self::hasPermission('manage_employee_accounts');
            }
        }
        
        // Owners can modify admins and users (but not other owners)
        if ($currentUserRole === 'owner') {
            return in_array($targetUserRole, ['admin', 'user']);
        }
        
        return false;
    }
    
    /**
     * Require specific permission or redirect
     */
    public static function requirePermission($permission, $redirectUrl = null) {
        if (!self::hasPermission($permission)) {
            $redirectUrl = $redirectUrl ?: BASE_URL . "dashboard";
            $_SESSION['error'] = "You don't have permission to access this feature.";
            $_SESSION['missing_permission'] = $permission; // For modal display
            header("Location: " . $redirectUrl);
            exit;
        }
    }
    
    /**
     * Require specific permission with AJAX response
     */
    public static function requirePermissionAjax($permission) {
        if (!self::hasPermission($permission)) {
            http_response_code(403);
            echo json_encode([
                'success' => false,
                'error' => 'Permission denied',
                'missing_permission' => $permission
            ]);
            exit;
        }
    }
    
    /**
     * Get all available permission templates
     */
    public static function getPermissionTemplates() {
        global $pdo;
        
        try {
            $stmt = $pdo->prepare("
                SELECT template_name, description, permissions 
                FROM whsale_inventory_pro_permission_templates 
                WHERE is_active = 1 
                ORDER BY template_name
            ");
            $stmt->execute();
            $templates = $stmt->fetchAll(PDO::FETCH_ASSOC);
            $stmt->closeCursor();
            
            // Decode JSON permissions (stored as TEXT)
            foreach ($templates as &$template) {
                $template['permissions'] = json_decode($template['permissions'], true);
                if (json_last_error() !== JSON_ERROR_NONE) {
                    // Fallback for malformed JSON
                    $template['permissions'] = [];
                }
            }
            
            return $templates;
        } catch (Exception $e) {
            error_log("Error fetching permission templates: " . $e->getMessage());
            return [];
        }
    }
    
    /**
     * Apply permission template to user
     */
    public static function applyPermissionTemplate($userId, $templateName, $grantedBy) {
    global $pdo;
    
    try {
        $pdo->beginTransaction();
        
        // Clear existing permissions
        $stmt = $pdo->prepare("DELETE FROM whsale_inventory_pro_user_permissions WHERE user_id = ?");
        $stmt->execute([$userId]);
        
        // Get template permissions
        $stmt = $pdo->prepare("
            SELECT permissions 
            FROM whsale_inventory_pro_permission_templates 
            WHERE template_name = ? AND is_active = 1
        ");
        $stmt->execute([$templateName]);
        $template = $stmt->fetch();
        
        if ($template) {
            $permissions = json_decode($template['permissions'], true);
            
            // Grant each permission WITH template name
            foreach ($permissions as $permission) {
                $stmt = $pdo->prepare("
                    INSERT INTO whsale_inventory_pro_user_permissions 
                    (user_id, permission_key, template_name, granted_by, granted_at) 
                    VALUES (?, ?, ?, ?, NOW())
                ");
                $stmt->execute([$userId, $permission, $templateName, $grantedBy]);
            }
        }
        
        $pdo->commit();
        
        // Refresh session permissions
        if ($userId == ($_SESSION['user_id'] ?? null)) {
            self::refreshUserPermissions($userId);
        }
        
        return true;
    } catch (Exception $e) {
        $pdo->rollback();
        error_log("Error applying permission template: " . $e->getMessage());
        return false;
    }
}
    
    /**
     * Revoke permission from user
     */
    public static function revokePermission($userId, $permission) {
        global $pdo;
        
        try {
            $stmt = $pdo->prepare("
                DELETE FROM whsale_inventory_pro_user_permissions 
                WHERE user_id = ? AND permission_key = ?
            ");
            $stmt->execute([$userId, $permission]);
            
            // Refresh permissions if this is the current user
            if ($userId == ($_SESSION['user_id'] ?? null)) {
                self::refreshUserPermissions($userId);
            }
            
            return true;
        } catch (Exception $e) {
            error_log("Error revoking permission: " . $e->getMessage());
            return false;
        }
    }
    
    /**
 * Grant individual permission to user (without template)
 */
public static function grantPermission($userId, $permission, $grantedBy) {
    global $pdo;
    
    try {
        $stmt = $pdo->prepare("
            INSERT INTO whsale_inventory_pro_user_permissions (user_id, permission_key, granted_by, granted_at)
            VALUES (?, ?, ?, NOW())
            ON DUPLICATE KEY UPDATE granted = 1, updated_at = NOW()
        ");
        $stmt->execute([$userId, $permission, $grantedBy]);
        
        // Refresh permissions if this is the current user
        if ($userId == ($_SESSION['user_id'] ?? null)) {
            self::refreshUserPermissions($userId);
        }
        
        return true;
    } catch (Exception $e) {
        error_log("Error granting permission: " . $e->getMessage());
        return false;
    }
}
    
    /**
     * Get user's current permissions
     */
    public static function getUserPermissions($userId) {
        global $pdo;
        
        try {
            $stmt = $pdo->prepare("CALL GetUserPermissions(?)");
            $stmt->execute([$userId]);
            $result = $stmt->fetch();
            $stmt->closeCursor();
            
            if ($result && $result['permissions']) {
                // Convert comma-separated string to array
                return explode(',', $result['permissions']);
            }
            
            return [];
        } catch (Exception $e) {
            error_log("Error getting user permissions: " . $e->getMessage());
            return [];
        }
    }
    
    /**
     * Legacy permission methods (for backward compatibility)
     */
    
    public static function canDelete() {
        return self::hasPermission('delete_inventory') || self::hasPermission('delete_receiving_logs');
    }
    
    public static function canManageUsers() {
        return self::hasPermission('manage_employee_accounts') || self::hasPermission('invite_employees');
    }
    
    public static function canInviteUsers() {
        return self::hasPermission('invite_employees');
    }
    
    public static function canManageOrganization() {
        return self::hasPermission('manage_organization_settings') || self::isOwner();
    }
    
    /**
     * Get role display name with badge (updated for owner)
     */
    public static function getRoleBadge($role = null) {
    $role = $role ?: ($_SESSION['user_role'] ?? 'admin');
    $badges = [
        'owner' => '<span class="badge bg-warning text-dark"><i class="fas fa-crown me-1"></i>Owner</span>',
        'admin' => '<span class="badge bg-info"><i class="fas fa-user-tag me-1"></i>Employee</span>', // Changed
        'user' => '<span class="badge bg-secondary"><i class="fas fa-user me-1"></i>User</span>' // Keep for legacy but won't show
    ];
    return $badges[$role] ?? $badges['admin'];
}
    
    /**
     * Get all defined permissions with descriptions
     */
    public static function getAllPermissions() {
        return [
            // User Management
            'invite_employees' => [
                'category' => 'User Management',
                'name' => 'Invite Employees',
                'description' => 'Send invitations to new team members'
            ],
            'manage_employee_accounts' => [
                'category' => 'User Management', 
                'name' => 'Manage Employee Accounts',
                'description' => 'Suspend, activate, and modify regular user accounts'
            ],
            'manage_admin_permissions' => [
                'category' => 'User Management',
                'name' => 'Manage Admin Permissions', 
                'description' => 'Modify permissions for other administrators'
            ],
            'view_user_activity' => [
                'category' => 'User Management',
                'name' => 'View User Activity',
                'description' => 'See who created and modified records'
            ],
            
            // Inventory Management
            'add_inventory' => [
                'category' => 'Inventory Management',
                'name' => 'Add Inventory Items',
                'description' => 'Create new inventory entries'
            ],
            'edit_inventory' => [
                'category' => 'Inventory Management',
                'name' => 'Edit Inventory Items', 
                'description' => 'Modify existing inventory records'
            ],
            'delete_inventory' => [
                'category' => 'Inventory Management',
                'name' => 'Delete Inventory Items',
                'description' => 'Remove inventory items permanently'
            ],
            'view_all_inventory' => [
                'category' => 'Inventory Management',
                'name' => 'View All Inventory',
                'description' => 'Access organization-wide inventory data'
            ],
            'manage_categories' => [
                'category' => 'Inventory Management',
                'name' => 'Manage Categories',
                'description' => 'Create and edit product categories'
            ],
            
            // Receiving Operations
            'create_receiving_logs' => [
                'category' => 'Receiving Operations',
                'name' => 'Create Receiving Logs',
                'description' => 'Add new receiving logs for deliveries'
            ],
            'edit_receiving_logs' => [
                'category' => 'Receiving Operations',
                'name' => 'Edit Receiving Logs',
                'description' => 'Modify existing receiving records'
            ],
            'delete_receiving_logs' => [
                'category' => 'Receiving Operations',
                'name' => 'Delete Receiving Logs',
                'description' => 'Remove receiving logs permanently'
            ],
            'upload_receiving_photos' => [
                'category' => 'Receiving Operations',
                'name' => 'Upload Receiving Photos',
                'description' => 'Add photos to receiving logs'
            ],
            'manage_receiving_photos' => [
                'category' => 'Receiving Operations',
                'name' => 'Manage Receiving Photos',
                'description' => 'Edit captions and delete photos from receiving logs'
            ],
            
            // Storefront Management
            'publish_to_storefront' => [
                'category' => 'Storefront Management',
                'name' => 'Publish to Storefront',
                'description' => 'Add inventory items to public storefront'
            ],
            'edit_storefront_listings' => [
                'category' => 'Storefront Management',
                'name' => 'Edit Storefront Listings',
                'description' => 'Modify published storefront products'
            ],
            'remove_storefront_listings' => [
                'category' => 'Storefront Management',
                'name' => 'Remove Storefront Listings',
                'description' => 'Unpublish and delete storefront products'
            ],
            'manage_storefront_branding' => [
                'category' => 'Storefront Management',
                'name' => 'Manage Storefront Branding',
                'description' => 'Edit storefront colors, logos, and appearance'
            ],
            'manage_customer_inquiries' => [
                'category' => 'Storefront Management',
                'name' => 'Manage Customer Inquiries',
                'description' => 'Handle customer contact forms and messages'
            ],
            
            // Data & Analytics
            'view_organization_data' => [
                'category' => 'Data & Analytics',
                'name' => 'View Organization Data',
                'description' => 'Access organization-wide data and reports'
            ],
            'export_inventory_data' => [
                'category' => 'Data & Analytics',
                'name' => 'Export Inventory Data',
                'description' => 'Download inventory reports and data exports'
            ],
            'export_receiving_data' => [
                'category' => 'Data & Analytics',
                'name' => 'Export Receiving Data',
                'description' => 'Download receiving logs and related data'
            ],
            'view_storefront_analytics' => [
                'category' => 'Data & Analytics',
                'name' => 'View Storefront Analytics',
                'description' => 'Access storefront performance metrics'
            ],
            'access_reports_dashboard' => [
                'category' => 'Data & Analytics',
                'name' => 'Access Reports Dashboard',
                'description' => 'View comprehensive analytics and reports'
            ],
            
            // System Administration
            'manage_organization_settings' => [
                'category' => 'System Administration',
                'name' => 'Manage Organization Settings',
                'description' => 'Edit organization profile and system settings'
            ]
        ];
    }
    
    /**
     * Get permissions grouped by category
     */
    public static function getPermissionsByCategory() {
        $permissions = self::getAllPermissions();
        $grouped = [];
        
        foreach ($permissions as $key => $permission) {
            $category = $permission['category'];
            if (!isset($grouped[$category])) {
                $grouped[$category] = [];
            }
            $grouped[$category][$key] = $permission;
        }
        
        return $grouped;
    }
    
    /**
     * Check if user has any permissions in a category
     */
    public static function hasAnyPermissionInCategory($category, $userId = null) {
        $permissions = self::getAllPermissions();
        
        foreach ($permissions as $key => $permission) {
            if ($permission['category'] === $category && self::hasPermission($key, $userId)) {
                return true;
            }
        }
        
        return false;
    }
    
    /**
     * Get role hierarchy level (for comparison)
     */
    public static function getRoleLevel($role) {
        $levels = [
            'user' => 1,
            'admin' => 2,
            'owner' => 3
        ];
        return $levels[$role] ?? 0;
    }
    
    /**
     * Check if current user has higher role than target user
     */
    public static function hasHigherRole($targetRole) {
        $currentRole = $_SESSION['user_role'] ?? 'user';
        return self::getRoleLevel($currentRole) > self::getRoleLevel($targetRole);
    }
    
    /**
     * Filter menu items based on user permissions
     */
    public static function getAvailableMenuItems() {
        $role = $_SESSION['user_role'] ?? 'user';
        
        $menuItems = [
            'dashboard' => [
                'title' => 'Dashboard',
                'url' => BASE_URL . 'dashboard',
                'icon' => 'fas fa-tachometer-alt',
                'permission' => null // Always available
            ],
            'receiving' => [
                'title' => 'Receiving',
                'url' => BASE_URL . 'receiving',
                'icon' => 'fas fa-truck',
                'permission' => 'create_receiving_logs'
            ],
            'inventory' => [
                'title' => 'Inventory',
                'url' => BASE_URL . 'inventory',
                'icon' => 'fas fa-boxes',
                'permission' => 'view_all_inventory'
            ],
            'storefront' => [
                'title' => 'Storefront',
                'url' => BASE_URL . 'storefront/manage',
                'icon' => 'fas fa-store',
                'permission' => 'publish_to_storefront'
            ],
            'admin_users' => [
                'title' => 'Manage Users',
                'url' => BASE_URL . 'admin/manage-users',
                'icon' => 'fas fa-users',
                'permission' => 'manage_employee_accounts'
            ],
            'admin_invite' => [
                'title' => 'Invite Employee',
                'url' => BASE_URL . 'admin/invite-employee',
                'icon' => 'fas fa-user-plus',
                'permission' => 'invite_employees'
            ],
            'admin_settings' => [
                'title' => 'Organization Settings',
                'url' => BASE_URL . 'admin/organization-settings',
                'icon' => 'fas fa-cog',
                'permission' => 'manage_organization_settings'
            ]
        ];
        
        // Filter menu items based on permissions
        $availableItems = [];
        foreach ($menuItems as $key => $item) {
            if (!$item['permission'] || self::hasPermission($item['permission'])) {
                $availableItems[$key] = $item;
            }
        }
        
        return $availableItems;
    }
}