<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Require specific permission for adding inventory
AuthHelper::requirePermission('add_inventory');

$receiving_id = $_GET['receiving_id'] ?? null;
if (!$receiving_id) {
    header("Location: " . BASE_URL . "receiving");
    exit;
}

$error = '';
$success = '';
$created_by = AuthHelper::getUserId();
$organization_id = $_SESSION['organization_id'];

// UPDATED: Verify receiving log belongs to user's organization
try {
    $stmt = $pdo->prepare("
        SELECT id, vendor_name 
        FROM whsale_inventory_pro_receiving_log 
        WHERE id = ? AND organization_id = ?
    ");
    $stmt->execute([$receiving_id, $organization_id]);
    $receiving_log = $stmt->fetch();
    $stmt->closeCursor();
    
    if (!$receiving_log) {
        throw new Exception("Receiving log not found or you don't have permission to access it.");
    }
} catch (Exception $e) {
    $_SESSION['error'] = $e->getMessage();
    header("Location: " . BASE_URL . "receiving");
    exit;
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $sku = trim($_POST['sku'] ?? '');
    $product_name = trim($_POST['product_name'] ?? '');
    $quantity = $_POST['quantity'] ?? 0;
    $unit_type = $_POST['unit_type'] ?? '';
    $expiration_date = $_POST['expiration_date'] ?? null;
    $location = trim($_POST['location'] ?? '');
    $notes = trim($_POST['notes'] ?? '');

    if ($product_name && $quantity > 0) {
        try {
            $stmt = $pdo->prepare("CALL whsale_inventory_pro_add_inventory_item(?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
            $stmt->execute([
                $receiving_id, $sku, $product_name, $quantity,
                $unit_type, $expiration_date, $location, $notes, $created_by, $organization_id
            ]);

            $item_id = $pdo->query("SELECT LAST_INSERT_ID()")->fetchColumn();
            $stmt->closeCursor();

            // Handle photo uploads (only if user has permission)
            if (!empty($_FILES['photos']['name'][0])) {
                $upload_dir = __DIR__ . '/../../public/uploads/inventory/';
                if (!is_dir($upload_dir)) mkdir($upload_dir, 0755, true);

                foreach ($_FILES['photos']['name'] as $index => $name) {
                    $tmp_name = $_FILES['photos']['tmp_name'][$index];
                    $errorCode = $_FILES['photos']['error'][$index];
                    $extension = strtolower(pathinfo($name, PATHINFO_EXTENSION));
                    $allowed = ['jpg', 'jpeg', 'png', 'gif', 'webp'];

                    if ($errorCode === UPLOAD_ERR_OK && in_array($extension, $allowed)) {
                        $filename = uniqid('item_') . '.' . $extension;
                        $filepath = $upload_dir . $filename;
                        if (move_uploaded_file($tmp_name, $filepath)) {
                            $stmt = $pdo->prepare("INSERT INTO whsale_inventory_pro_inventory_photos (item_id, file_path, uploaded_by) VALUES (?, ?, ?)");
                            $stmt->execute([$item_id, $filename, $created_by]);
                        }
                    }
                }
            }

            $success = "Item added successfully.";
        } catch (Exception $e) {
            $error = "Failed to add item: " . $e->getMessage();
        }
    } else {
        $error = "Product name and quantity are required.";
    }
}
?>

<?php include __DIR__ . '/../partials/head.php'; ?>
<?php include __DIR__ . '/../partials/spinner_overlay.php'; ?>

<div class="container mt-4 mb-5">
    <div class="d-flex align-items-center mb-3">
        <h4 class="mb-0">Add Inventory Item to Receiving Log</h4>
        <div class="ms-auto">
            <?= RoleHelper::getRoleBadge() ?>
        </div>
    </div>

    <!-- UPDATED: Add receiving log info card -->
    <div class="alert alert-info mb-4">
        <div class="d-flex align-items-center">
            <i class="fas fa-truck me-2"></i>
            <div>
                <strong>Adding to:</strong> Receiving Log #<?= htmlspecialchars($receiving_id) ?>
                <?php if ($receiving_log): ?>
                    from <?= htmlspecialchars($receiving_log['vendor_name']) ?>
                <?php endif; ?>
                <br>
                <small class="text-muted">This item will be linked to the receiving log for tracking purposes.</small>
            </div>
        </div>
    </div>

    <?php if ($success): ?>
        <div class="alert alert-success">
            <i class="fas fa-check-circle me-2"></i>
            <?= htmlspecialchars($success) ?>
        </div>
    <?php endif; ?>
    <?php if ($error): ?>
        <div class="alert alert-danger">
            <i class="fas fa-exclamation-circle me-2"></i>
            <?= htmlspecialchars($error) ?>
        </div>
    <?php endif; ?>

    <!-- Responsive Form -->
    <form method="POST" enctype="multipart/form-data" class="card p-4 shadow-sm border-0 bg-white" onsubmit="showSpinner()">
        <div class="row">
            <div class="col-md-6 mb-3">
                <label class="form-label">SKU (Scan Barcode or Insert Manually)</label>
                <input type="text" name="sku" class="form-control" id="skuInput" autofocus
                       placeholder="Scan or type SKU">
                <div class="form-text">
                    <i class="fas fa-barcode me-1"></i>
                    Optional - helps with inventory tracking
                </div>
            </div>
            <div class="col-md-6 mb-3">
                <label class="form-label">Product Name <span class="text-danger">*</span></label>
                <input type="text" name="product_name" class="form-control" required
                       placeholder="Enter the product name">
            </div>
        </div>

        <div class="row">
            <div class="col-md-4 mb-3">
                <label class="form-label">Quantity <span class="text-danger">*</span></label>
                <input type="number" name="quantity" class="form-control" required step="0.01"
                       placeholder="0.00">
            </div>
            <div class="col-md-4 mb-3">
                <label class="form-label">Unit Type</label>
                <select name="unit_type" class="form-select">
                    <option value="">Select...</option>
                    <option value="cases">Cases</option>
                    <option value="lbs">Lbs</option>
                    <option value="boxes">Boxes</option>
                    <option value="cans">Cans</option>
                    <option value="units">Units</option>
                    <option value="pallets">Pallets</option>
                </select>
            </div>
            <div class="col-md-4 mb-3">
                <label class="form-label">Expiration Date</label>
                <input type="date" name="expiration_date" class="form-control">
                <div class="form-text">
                    <i class="fas fa-calendar me-1"></i>
                    Leave blank if no expiration
                </div>
            </div>
        </div>

        <div class="row">
            <div class="col-md-6 mb-3">
                <label class="form-label">Storage Location</label>
                <input type="text" name="location" class="form-control"
                       placeholder="Warehouse, freezer, etc.">
            </div>
            <div class="col-md-6 mb-3">
                <label class="form-label">Notes</label>
                <textarea name="notes" class="form-control" rows="3"
                          placeholder="Any additional information..."></textarea>
            </div>
        </div>

        <div class="mb-3">
            <label class="form-label">Upload Item Photos (Optional)</label>
            <input type="file" name="photos[]" class="form-control" multiple accept="image/*" onchange="previewImages(event)">
            <div class="form-text">
                <i class="fas fa-camera me-1"></i>
                Document the condition and details of this item
            </div>
            <div id="imagePreview" class="d-flex flex-wrap gap-2 mt-2"></div>
        </div>

        <div class="d-flex flex-wrap gap-2 justify-content-between align-items-center">
            <button class="btn btn-dark">
                <i class="fas fa-plus me-1"></i>Add Item
            </button>
            <div class="d-flex gap-2">
                <a href="<?= BASE_URL ?>receiving/view?id=<?= urlencode($receiving_id) ?>" class="btn btn-outline-secondary">
                    <i class="fas fa-arrow-left me-1"></i>Back to Log
                </a>
                
                <?php if (RoleHelper::hasPermission('view_all_inventory')): ?>
                    <a href="<?= BASE_URL ?>inventory" class="btn btn-outline-primary" data-permission="view_all_inventory">
                        <i class="fas fa-boxes me-1"></i>View All Inventory
                    </a>
                <?php endif; ?>
            </div>
        </div>
    </form>

    <!-- UPDATED: Add helpful tips card -->
    <div class="card mt-4 border-0 bg-light">
        <div class="card-body">
            <h6 class="card-title">
                <i class="fas fa-lightbulb me-2"></i>Tips for Adding Inventory
            </h6>
            <ul class="mb-0 small">
                <li><strong>SKU:</strong> Use your barcode scanner or type manually for easier tracking</li>
                <li><strong>Quantity:</strong> Be precise - decimals are allowed (e.g., 2.5 cases)</li>
                <li><strong>Location:</strong> Specify where the item is stored for quick retrieval</li>
                <li><strong>Photos:</strong> Document any damage, special handling requirements, or unique features</li>
                <li><strong>Expiration:</strong> Set dates for perishable items to track freshness</li>
            </ul>
        </div>
    </div>
</div>

<script>
function showSpinner() {
    const overlay = document.getElementById('globalSpinnerOverlay');
    if (overlay) {
        overlay.classList.remove('d-none');
        overlay.style.opacity = 0;
        overlay.style.transition = 'opacity 0.3s ease-in-out';
        setTimeout(() => overlay.style.opacity = 1, 10);
    }
}

document.addEventListener("DOMContentLoaded", function () {
    const skuInput = document.querySelector('input[name="sku"]');
    if (skuInput) {
        skuInput.focus();
        skuInput.addEventListener("input", () => {
            skuInput.classList.add("border-success");
            setTimeout(() => skuInput.classList.remove("border-success"), 500);
        });
    }
});

function previewImages(event) {
    const preview = document.getElementById('imagePreview');
    preview.innerHTML = '';
    const files = event.target.files;
    Array.from(files).forEach(file => {
        const reader = new FileReader();
        reader.onload = e => {
            const img = document.createElement('img');
            img.src = e.target.result;
            img.className = 'img-thumbnail';
            img.style.width = '100px';
            img.style.height = '100px';
            img.style.objectFit = 'cover';
            preview.appendChild(img);
        };
        reader.readAsDataURL(file);
    });
}
</script>

<!-- UPDATED: Custom CSS for enhanced UX -->
<style>
/* Alert styling */
.alert-info {
    border-left: 4px solid #0dcaf0;
}

/* Form enhancements */
.form-control:focus, .form-select:focus {
    border-color: #0d6efd;
    box-shadow: 0 0 0 0.2rem rgba(13, 110, 253, 0.25);
}

/* SKU input special styling */
#skuInput.border-success {
    border-color: #198754 !important;
    box-shadow: 0 0 0 0.2rem rgba(25, 135, 84, 0.25) !important;
}

/* Tips card styling */
.bg-light {
    background-color: #f8f9fa !important;
}

/* Image preview styling */
#imagePreview img {
    border-radius: 8px;
    box-shadow: 0 2px 4px rgba(0,0,0,0.1);
}

/* Mobile responsiveness */
@media (max-width: 768px) {
    .d-flex.flex-wrap.gap-2 {
        flex-direction: column;
    }
    
    .btn {
        text-align: center;
    }
    
    .d-flex.gap-2 {
        flex-direction: column;
    }
}

/* Permission-protected elements */
[data-permission].permission-denied {
    opacity: 0.6;
    pointer-events: none;
    position: relative;
}

[data-permission].permission-denied::after {
    content: "\f023";
    font-family: "Font Awesome 5 Free";
    font-weight: 900;
    position: absolute;
    top: 50%;
    right: 8px;
    transform: translateY(-50%);
    color: #dc3545;
    font-size: 12px;
}
</style>

<?php include __DIR__ . '/../partials/footer.php'; ?>