<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Require specific permission for deleting photos
AuthHelper::requireLogin();

header('Content-Type: application/json');

// Check if user has permission (owners automatically have all permissions)
if (!RoleHelper::isOwner() && !RoleHelper::hasPermission('delete_inventory')) {
    http_response_code(403);
    echo json_encode([
        'success' => false,
        'error' => 'Permission denied',
        'missing_permission' => 'delete_inventory'
    ]);
    exit;
}

$photo_id = $_POST['photo_id'] ?? null;
$user_id = AuthHelper::getUserId();
$organization_id = $_SESSION['organization_id'];

if (!$photo_id || !is_numeric($photo_id)) {
    http_response_code(400);
    echo json_encode(['success' => false, 'error' => 'Invalid photo ID.']);
    exit;
}

try {
    // UPDATED: Enhanced security - verify photo belongs to user's organization
    $stmt = $pdo->prepare("
        SELECT ip.id, ip.file_path 
        FROM whsale_inventory_pro_inventory_photos ip
        JOIN whsale_inventory_pro_inventory_items ii ON ip.item_id = ii.id
        WHERE ip.id = ? AND ii.organization_id = ?
    ");
    $stmt->execute([$photo_id, $organization_id]);
    $photo = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$photo) {
        http_response_code(404);
        echo json_encode(['success' => false, 'error' => 'Photo not found or access denied.']);
        exit;
    }

    // Delete from database first
    $stmt = $pdo->prepare("DELETE FROM whsale_inventory_pro_inventory_photos WHERE id = ?");
    $stmt->execute([$photo_id]);

    // Attempt to delete the file from the server
    $file_path = __DIR__ . '/../../public/uploads/inventory/' . $photo['file_path'];
    if (file_exists($file_path)) {
        unlink($file_path);
    }

    echo json_encode([
        'success' => true,
        'message' => 'Photo deleted successfully'
    ]);
} catch (Exception $e) {
    error_log("Error deleting inventory photo: " . $e->getMessage());
    http_response_code(500);
    echo json_encode(['success' => false, 'error' => 'Failed to delete photo.']);
}