<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Require specific permission for editing inventory
AuthHelper::requirePermission('edit_inventory');

$inventory_id = $_GET['id'] ?? null;
$from = $_GET['from'] ?? null;
$from = $_POST['from'] ?? ($_GET['from'] ?? null);

if (!$inventory_id || !is_numeric($inventory_id)) {
    header("Location: " . BASE_URL . "inventory");
    exit;
}

$error = '';
$success = '';
$item = null;
$photos = [];
$created_by = AuthHelper::getUserId();
$organization_id = $_SESSION['organization_id'];

// Load current item data
try {
    // UPDATED: Enhanced security - verify item belongs to user's organization
    $stmt = $pdo->prepare("
        SELECT * FROM whsale_inventory_pro_inventory_items 
        WHERE id = ? AND organization_id = ?
    ");
    $stmt->execute([$inventory_id, $organization_id]);
    $item = $stmt->fetch();
    $stmt->closeCursor();

    if (!$item) {
        throw new Exception("Item not found or you don't have permission to access it.");
    }
} catch (Exception $e) {
    $error = $e->getMessage();
}

// Load existing photos
try {
    $stmt = $pdo->prepare("SELECT * FROM whsale_inventory_pro_inventory_photos WHERE item_id = ? ORDER BY uploaded_at DESC");
    $stmt->execute([$inventory_id]);
    $photos = $stmt->fetchAll();
    $stmt->closeCursor();
} catch (Exception $e) {
    error_log("Failed to load photos: " . $e->getMessage());
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Handle delete action
    if (isset($_POST['delete_item'])) {
        if (!RoleHelper::hasPermission('delete_inventory')) {
            $error = "You don't have permission to delete inventory items.";
        } else {
            try {
                $stmt = $pdo->prepare("CALL whsale_inventory_pro_soft_delete_inventory_item(?, ?)");
                $stmt->execute([$inventory_id, $created_by]);
                $stmt->closeCursor();
                
                $_SESSION['success'] = "Inventory item has been deleted successfully.";
                
                // Redirect based on where user came from
                if ($from === 'inventory') {
                    header("Location: " . BASE_URL . "inventory/manage");
                } elseif ($item['receiving_id']) {
                    header("Location: " . BASE_URL . "receiving/view?id=" . urlencode($item['receiving_id']));
                } else {
                    header("Location: " . BASE_URL . "inventory");
                }
                exit;
            } catch (Exception $e) {
                $error = "Delete failed: " . $e->getMessage();
            }
        }
    }
    
    // Handle regular update
    else {
        $sku = trim($_POST['sku'] ?? '');
        $product_name = trim($_POST['product_name'] ?? '');
        $quantity = $_POST['quantity'] ?? 0;
        $unit_type = $_POST['unit_type'] ?? '';
        $expiration_date = $_POST['expiration_date'] ?? null;
        $location = trim($_POST['location'] ?? '');
        $notes = trim($_POST['notes'] ?? '');

        if ($product_name && $quantity > 0) {
            try {
                $pdo->beginTransaction();

                // Update inventory item
                $stmt = $pdo->prepare("CALL whsale_inventory_pro_update_inventory_item(?, ?, ?, ?, ?, ?, ?, ?)");
                $stmt->execute([
                    $inventory_id, $sku, $product_name, $quantity,
                    $unit_type, $expiration_date, $location, $notes
                ]);
                $stmt->closeCursor();
                
                $itemUpdated = true;

                // Handle new photo uploads
                $newPhotosUploaded = 0;
                if (!empty($_FILES['photos']['name'][0])) {
                    $upload_dir = __DIR__ . '/../../public/uploads/inventory/';
                    if (!is_dir($upload_dir)) mkdir($upload_dir, 0755, true);

                    foreach ($_FILES['photos']['name'] as $index => $name) {
                        $tmp_name = $_FILES['photos']['tmp_name'][$index];
                        $errorCode = $_FILES['photos']['error'][$index];
                        $extension = strtolower(pathinfo($name, PATHINFO_EXTENSION));
                        $allowed = ['jpg', 'jpeg', 'png', 'gif', 'webp'];

                        if ($errorCode === UPLOAD_ERR_OK && in_array($extension, $allowed)) {
                            $filename = uniqid('item_') . '.' . $extension;
                            $filepath = $upload_dir . $filename;
                            if (move_uploaded_file($tmp_name, $filepath)) {
                                $stmt = $pdo->prepare("INSERT INTO whsale_inventory_pro_inventory_photos (item_id, file_path, uploaded_by) VALUES (?, ?, ?)");
                                $stmt->execute([$inventory_id, $filename, $created_by]);
                                $newPhotosUploaded++;
                            }
                        }
                    }
                }

                // UPDATED: Handle photo caption updates (like receiving/edit.php)
                $captionsUpdated = 0;
                if (isset($_POST['photo_captions']) && is_array($_POST['photo_captions'])) {
                    foreach ($_POST['photo_captions'] as $photo_id => $caption) {
                        if (is_numeric($photo_id)) {
                            // Verify photo belongs to this item
                            $stmt = $pdo->prepare("
                                SELECT id, caption 
                                FROM whsale_inventory_pro_inventory_photos 
                                WHERE id = ? AND item_id = ?
                            ");
                            $stmt->execute([$photo_id, $inventory_id]);
                            $photoData = $stmt->fetch();
                            
                            if ($photoData) {
                                $newCaption = trim($caption);
                                $oldCaption = trim($photoData['caption'] ?? '');
                                
                                // Only update if caption actually changed
                                if ($newCaption !== $oldCaption) {
                                    $stmt = $pdo->prepare("UPDATE whsale_inventory_pro_inventory_photos SET caption = ? WHERE id = ?");
                                    $stmt->execute([$newCaption, $photo_id]);
                                    if ($stmt->rowCount() > 0) {
                                        $captionsUpdated++;
                                    }
                                }
                            }
                        }
                    }
                }

                $pdo->commit();
                
                // Build success message
                $successParts = [];
                if ($itemUpdated) $successParts[] = "item details";
                if ($newPhotosUploaded > 0) $successParts[] = "$newPhotosUploaded new photo(s)";
                if ($captionsUpdated > 0) $successParts[] = "$captionsUpdated caption(s)";
                
                $success = "Successfully updated " . implode(", ", $successParts) . ".";

                // Reload item data
                $stmt = $pdo->prepare("SELECT * FROM whsale_inventory_pro_inventory_items WHERE id = ? AND organization_id = ?");
                $stmt->execute([$inventory_id, $organization_id]);
                $item = $stmt->fetch();
                $stmt->closeCursor();

                // Reload photos
                $stmt = $pdo->prepare("SELECT * FROM whsale_inventory_pro_inventory_photos WHERE item_id = ? ORDER BY uploaded_at DESC");
                $stmt->execute([$inventory_id]);
                $photos = $stmt->fetchAll();
                $stmt->closeCursor();

            } catch (Exception $e) {
                $pdo->rollback();
                $error = "Failed to update item: " . $e->getMessage();
            }
        } else {
            $error = "Product name and quantity are required.";
        }
    }
}

// Available unit types
$unitOptions = ['Cases', 'Lbs', 'Boxes', 'Cans', 'Units', 'Pallets'];
?>

<?php include __DIR__ . '/../partials/head.php'; ?>
<?php include __DIR__ . '/../partials/spinner_overlay.php'; ?>

<div class="container mt-4 mb-5">
    <div class="d-flex align-items-center mb-3">
        <h4 class="mb-0 me-3">Edit Inventory Item</h4>
        <?php if ($item && !empty($item['sku'])): ?>
            <span class="badge bg-secondary">
                <i class="fas fa-barcode me-1"></i><?= htmlspecialchars($item['sku']) ?>
            </span>
        <?php endif; ?>
        <div class="ms-auto">
            <?= RoleHelper::getRoleBadge() ?>
        </div>
    </div>

    <!-- Options Dropdown -->
    <div class="d-flex justify-content-between align-items-center mb-4">
        <div></div>
        <div class="dropdown">
            <button class="btn btn-outline-secondary btn-sm dropdown-toggle" type="button" 
                    id="optionsDropdown" data-bs-toggle="dropdown" aria-expanded="false">
                <i class="fas fa-cog me-1"></i>Options
            </button>
            <ul class="dropdown-menu dropdown-menu-end" aria-labelledby="optionsDropdown">
                <?php if (RoleHelper::hasPermission('delete_inventory')): ?>
                    <li>
                        <a class="dropdown-item text-danger" href="#" 
                           onclick="confirmDeleteItem(<?= $inventory_id ?>); return false;">
                            <i class="fas fa-trash me-2"></i>Delete Item
                        </a>
                    </li>
                    <li><hr class="dropdown-divider"></li>
                <?php endif; ?>
                <li>
                    <a class="dropdown-item" href="<?= BASE_URL ?>inventory/view?id=<?= urlencode($inventory_id) ?><?= $from ? '&from=' . urlencode($from) : '' ?>">
                        <i class="fas fa-eye me-2"></i>View Details
                    </a>
                </li>
            </ul>
        </div>
    </div>

    <?php if ($success): ?>
        <div class="alert alert-success">
            <i class="fas fa-check-circle me-2"></i>
            <?= htmlspecialchars($success) ?>
        </div>
    <?php endif; ?>
    <?php if ($error): ?>
        <div class="alert alert-danger">
            <i class="fas fa-exclamation-circle me-2"></i>
            <?= htmlspecialchars($error) ?>
        </div>
    <?php endif; ?>

    <?php if ($item): ?>
        <!-- UPDATED: Single form for all changes -->
        <form method="POST" enctype="multipart/form-data" onsubmit="showSpinner()">
            <input type="hidden" name="from" value="<?= htmlspecialchars($from ?? '') ?>">

            <!-- Main form fields -->
            <div class="card p-4 shadow-sm border-0 bg-white mb-4">
                <h6 class="mb-3">
                    <i class="fas fa-edit me-2"></i>Item Details
                </h6>
                
                <div class="row">
                    <div class="col-md-6 mb-3">
                        <label class="form-label">SKU</label>
                        <input type="text" name="sku" class="form-control" value="<?= htmlspecialchars($item['sku']) ?>">
                        <div class="form-text">
                            <i class="fas fa-barcode me-1"></i>
                            Scan barcode or enter manually
                        </div>
                    </div>
                    <div class="col-md-6 mb-3">
                        <label class="form-label">Product Name <span class="text-danger">*</span></label>
                        <input type="text" name="product_name" class="form-control" 
                               value="<?= htmlspecialchars($item['product_name']) ?>" required>
                    </div>
                </div>

                <div class="row">
                    <div class="col-md-4 mb-3">
                        <label class="form-label">Quantity <span class="text-danger">*</span></label>
                        <input type="number" name="quantity" class="form-control" required step="any" 
                               value="<?= htmlspecialchars($item['quantity']) ?>">
                    </div>
                    <div class="col-md-4 mb-3">
                        <label class="form-label">Unit Type</label>
                        <select name="unit_type" class="form-select">
                            <option value="">Select...</option>
                            <?php foreach ($unitOptions as $option): ?>
                                <option value="<?= $option ?>" <?= $item['unit_type'] === $option ? 'selected' : '' ?>>
                                    <?= ucfirst($option) ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="col-md-4 mb-3">
                        <label class="form-label">Expiration Date</label>
                        <input type="date" name="expiration_date" class="form-control" 
                               value="<?= htmlspecialchars($item['expiration_date']) ?>">
                    </div>
                </div>

                <div class="row">
                    <div class="col-md-6 mb-3">
                        <label class="form-label">Storage Location</label>
                        <input type="text" name="location" class="form-control" 
                               value="<?= htmlspecialchars($item['location']) ?>">
                    </div>
                    <div class="col-md-6 mb-3">
                        <label class="form-label">Notes</label>
                        <textarea name="notes" class="form-control" rows="3"><?= htmlspecialchars($item['notes']) ?></textarea>
                    </div>
                </div>

                <div class="mb-3">
                    <label class="form-label">Upload New Photos (Optional)</label>
                    <input type="file" name="photos[]" class="form-control" multiple accept="image/*" onchange="previewImages(event)">
                    <div class="form-text">
                        <i class="fas fa-camera me-1"></i>
                        Add new photos to this inventory item
                    </div>
                    <div id="imagePreview" class="d-flex flex-wrap gap-2 mt-2"></div>
                </div>
            </div>

            <!-- UPDATED: Photo section integrated into the form -->
            <?php if (!empty($photos)): ?>
                <div class="card border-0 shadow-sm mb-4">
                    <div class="card-header bg-white">
                        <h6 class="mb-0">
                            <i class="fas fa-images me-2"></i>Edit Item Photos
                            <span class="badge bg-secondary ms-2"><?= count($photos) ?></span>
                        </h6>
                    </div>
                    <div class="card-body">
                        <div class="row g-3">
                            <?php foreach ($photos as $photo): ?>
                                <div class="col-6 col-md-4 col-lg-3">
                                    <div class="card">
                                        <img src="<?= BASE_URL ?>public/uploads/inventory/<?= htmlspecialchars($photo['file_path']) ?>" 
                                             class="card-img-top" alt="Photo" style="height: 180px; object-fit: cover;">
                                        <div class="card-body p-2">
                                            <!-- UPDATED: Caption input integrated into form -->
                                            <input type="text" 
                                                   class="form-control form-control-sm mb-2" 
                                                   name="photo_captions[<?= $photo['id'] ?>]"
                                                   value="<?= htmlspecialchars($photo['caption'] ?? '') ?>" 
                                                   placeholder="Edit caption...">
                                            
                                            <!-- Delete button for photos -->
                                            <?php if (RoleHelper::hasPermission('delete_inventory')): ?>
                                                <button type="button" class="btn btn-sm btn-outline-danger w-100 btn-delete-photo" 
                                                        data-photo-id="<?= $photo['id'] ?>">
                                                    <i class="fas fa-trash me-1"></i>Delete Photo
                                                </button>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            <?php endif; ?>

            <!-- UPDATED: Moved action buttons to bottom of form -->
            <div class="card p-4 shadow-sm border-0 bg-light">
                <div class="d-flex flex-wrap gap-2 justify-content-between align-items-center">
                    <div>
                        <h6 class="mb-1">
                            <i class="fas fa-save me-2"></i>Save All Changes
                        </h6>
                        <small class="text-muted">
                            This will save all item details, new photos, and photo captions together.
                        </small>
                    </div>
                    <div class="d-flex gap-2">
                        <button type="submit" class="btn btn-dark">
                            <i class="fas fa-save me-1"></i>Save Changes
                        </button>
                        <a href="<?= BASE_URL ?>inventory/view?id=<?= urlencode($inventory_id) ?><?= $from ? '&from=' . urlencode($from) : '' ?>" class="btn btn-outline-secondary">
                            <i class="fas fa-times me-1"></i>Cancel
                        </a>
                    </div>
                </div>
            </div>
        </form>
    <?php endif; ?>
</div>

<!-- Custom CSS -->
<style>
/* Options Dropdown Styling */
.dropdown-menu .dropdown-item.text-danger:hover {
    background-color: #dc3545;
    color: white;
}

.dropdown-menu .dropdown-item {
    transition: all 0.2s ease;
}

.dropdown-menu .dropdown-item:hover {
    background-color: #f8f9fa;
}

/* Form sections styling */
.card h6 {
    color: #495057;
}

.bg-light .card {
    background-color: #f8f9fa !important;
}

/* Image preview styling */
#imagePreview img {
    border-radius: 8px;
    box-shadow: 0 2px 4px rgba(0,0,0,0.1);
}

/* Responsive adjustments */
@media (max-width: 768px) {
    .d-flex.justify-content-between {
        flex-direction: column;
        gap: 1rem;
    }
    
    .dropdown {
        align-self: flex-end;
    }
    
    .d-flex.gap-2 {
        flex-direction: column;
    }
    
    .btn {
        text-align: center;
    }
}
</style>

<script>
function showSpinner() {
    const overlay = document.getElementById('globalSpinnerOverlay');
    if (overlay) {
        overlay.classList.remove('d-none');
        overlay.style.opacity = 0;
        overlay.style.transition = 'opacity 0.3s ease-in-out';
        setTimeout(() => overlay.style.opacity = 1, 10);
    }
}

function previewImages(event) {
    const preview = document.getElementById('imagePreview');
    preview.innerHTML = '';
    const files = event.target.files;
    Array.from(files).forEach(file => {
        const reader = new FileReader();
        reader.onload = e => {
            const img = document.createElement('img');
            img.src = e.target.result;
            img.className = 'img-thumbnail';
            img.style.width = '100px';
            img.style.height = '100px';
            img.style.objectFit = 'cover';
            preview.appendChild(img);
        };
        reader.readAsDataURL(file);
    });
}

// UPDATED: Remove auto-save functionality for photo captions
// Photo captions will now be saved with the main form

// Delete photo functionality
document.addEventListener('DOMContentLoaded', function() {
    document.querySelectorAll('.btn-delete-photo').forEach(btn => {
        btn.addEventListener('click', function () {
            if (!confirm("Delete this photo? This action cannot be undone.")) return;
            const photoId = this.dataset.photoId;
            fetch("<?= BASE_URL ?>inventory/delete_photo", {
                method: "POST",
                headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
                body: `photo_id=${photoId}`
            }).then(() => location.reload());
        });
    });
});

// Handle item delete confirmation
function confirmDeleteItem(itemId) {
    const confirmed = confirm(
        "Are you sure you want to delete this inventory item?\n\n" +
        "This action cannot be undone.\n\n" +
        "Click OK to proceed with deletion."
    );
    
    if (confirmed) {
        // Create and submit a hidden form for the delete action
        const form = document.createElement('form');
        form.method = 'POST';
        form.style.display = 'none';
        
        const deleteInput = document.createElement('input');
        deleteInput.type = 'hidden';
        deleteInput.name = 'delete_item';
        deleteInput.value = '1';
        
        const fromInput = document.createElement('input');
        fromInput.type = 'hidden';
        fromInput.name = 'from';
        fromInput.value = '<?= htmlspecialchars($from ?? '') ?>';
        
        form.appendChild(deleteInput);
        form.appendChild(fromInput);
        document.body.appendChild(form);
        form.submit();
    }
}
</script>

<?php if ($success): ?>
<script>
    document.addEventListener('DOMContentLoaded', () => {
        // Show success message briefly
        setTimeout(() => {
            // Auto-redirect disabled to let user see their changes
        }, 1500);
    });
</script>
<?php endif; ?>

<?php include __DIR__ . '/../partials/footer.php'; ?>