<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Basic login required for viewing (all users can view)
AuthHelper::requireLogin();

if (isset($_GET['from_receiving'])) {
    $_SESSION['came_from_receiving_view'] = $_GET['from_receiving'];
} elseif (isset($_GET['from']) && $_GET['from'] === 'inventory') {
    unset($_SESSION['came_from_receiving_view']);
}

$from = $_GET['from'] ?? null;
$item_id = $_GET['id'] ?? null;
if (!$item_id || !is_numeric($item_id)) {
    header("Location: " . BASE_URL . "inventory");
    exit;
}

$error = '';
$item = null;
$photos = [];
$organization_id = $_SESSION['organization_id'];

try {
    // UPDATED: Enhanced security - verify item belongs to user's organization
    $stmt = $pdo->prepare("
        SELECT * FROM whsale_inventory_pro_inventory_items 
        WHERE id = ? AND organization_id = ?
    ");
    $stmt->execute([$item_id, $organization_id]);
    $item = $stmt->fetch();
    $stmt->closeCursor();

    if (!$item) {
        throw new Exception("Inventory item not found or you don't have permission to access it.");
    }

    // Call procedure to get photos
    $stmt = $pdo->prepare("CALL whsale_inventory_pro_get_inventory_photos_by_item(?)");
    $stmt->execute([$item_id]);
    $photos = $stmt->fetchAll();
    $stmt->closeCursor();
} catch (Exception $e) {
    $error = $e->getMessage();
}
?>

<?php include __DIR__ . '/../partials/head.php'; ?>

<div class="container mt-4 mb-5">
    <div class="d-flex flex-wrap gap-2 justify-content-between align-items-center mb-3">
        <div>
            <h4 class="mb-0"><?= $item ? htmlspecialchars($item['product_name']) : 'Inventory Item' ?></h4>
            <?php if ($item && !empty($item['sku'])): ?>
                <small class="text-muted">SKU: <?= htmlspecialchars($item['sku']) ?></small>
            <?php endif; ?>
        </div>
        
        <div class="d-flex gap-2 flex-wrap">
            <!-- UPDATED: Edit button with permission check -->
            <?php if ($item && RoleHelper::hasPermission('edit_inventory')): ?>
                <a href="<?= BASE_URL ?>inventory/edit?id=<?= urlencode($item_id) ?>&from=<?= urlencode($from ?? 'inventory') ?>" 
                   class="btn btn-sm btn-outline-primary" data-permission="edit_inventory">
                    <i class="fas fa-edit me-1"></i>Edit Item
                </a>
            <?php endif; ?>
            
            <!-- UPDATED: Delete button with permission check -->
            <?php if ($item && RoleHelper::hasPermission('delete_inventory')): ?>
                <button class="btn btn-sm btn-outline-danger" 
                        onclick="confirmDeleteItem(<?= $item_id ?>)" 
                        data-permission="delete_inventory">
                    <i class="fas fa-trash me-1"></i>Delete Item
                </button>
            <?php endif; ?>
        </div>
    </div>

    <?php if ($error): ?>
        <div class="alert alert-danger">
            <i class="fas fa-exclamation-circle me-2"></i>
            <?= htmlspecialchars($error) ?>
        </div>
    <?php elseif ($item): ?>
        <div class="card shadow-sm border-0 mb-4">
            <div class="card-body">
                <div class="row">
                    <div class="col-md-6">
                        <p><strong>SKU:</strong> <?= htmlspecialchars($item['sku']) ?: 'Not specified' ?></p>
                        <p><strong>Quantity:</strong> <?= htmlspecialchars($item['quantity']) ?> <?= htmlspecialchars($item['unit_type']) ?></p>
                        <p><strong>Expiration Date:</strong> 
                            <?php if ($item['expiration_date']): ?>
                                <?= date('M d, Y', strtotime($item['expiration_date'])) ?>
                                <?php 
                                $daysUntilExpiry = floor((strtotime($item['expiration_date']) - time()) / 86400);
                                if ($daysUntilExpiry < 0): ?>
                                    <span class="badge bg-danger ms-1">Expired</span>
                                <?php elseif ($daysUntilExpiry <= 7): ?>
                                    <span class="badge bg-warning text-dark ms-1">Expires soon</span>
                                <?php endif; ?>
                            <?php else: ?>
                                <span class="text-muted">Not specified</span>
                            <?php endif; ?>
                        </p>
                    </div>
                    <div class="col-md-6">
                        <p><strong>Storage Location:</strong> <?= htmlspecialchars($item['location']) ?: 'Not specified' ?></p>
                        <p><strong>Added to Inventory:</strong> <?= date('M d, Y g:i A', strtotime($item['created_at'])) ?></p>
                        <?php if ($item['receiving_id']): ?>
                            <p><strong>From Receiving Log:</strong> 
                                <a href="<?= BASE_URL ?>receiving/view?id=<?= urlencode($item['receiving_id']) ?>" class="text-decoration-none">
                                    #<?= htmlspecialchars($item['receiving_id']) ?>
                                </a>
                            </p>
                        <?php endif; ?>
                    </div>
                </div>
                
                <?php if (!empty($item['notes'])): ?>
                    <div class="mt-3 pt-3 border-top">
                        <p><strong>Notes:</strong><br><?= nl2br(htmlspecialchars($item['notes'])) ?></p>
                    </div>
                <?php endif; ?>
            </div>
        </div>

        <!-- UPDATED: Photos section with permission-based actions -->
        <?php if (!empty($photos)): ?>
            <div class="card border-0 shadow-sm mb-4">
                <div class="card-header bg-white d-flex justify-content-between align-items-center">
                    <button class="btn btn-sm btn-outline-secondary d-flex align-items-center gap-1" type="button"
                        data-bs-toggle="collapse"
                        data-bs-target="#inventoryPhotosCollapse"
                        aria-expanded="false"
                        aria-controls="inventoryPhotosCollapse">
                        <i class="bi bi-images"></i> Show/Hide Item Photos (<?= count($photos) ?>)
                    </button>
                    
                    <?php if (RoleHelper::hasPermission('edit_inventory')): ?>
                        <small class="text-muted">
                            <i class="fas fa-info-circle me-1"></i>
                            Use the edit page to manage photos
                        </small>
                    <?php endif; ?>
                </div>
                <div class="collapse" id="inventoryPhotosCollapse">
                    <div class="card-body">
                        <div class="row g-3">
                            <?php foreach ($photos as $photo): ?>
                                <div class="col-6 col-md-4 col-lg-3">
                                    <div class="border rounded shadow-sm p-2 bg-light text-center">
                                        <a href="<?= BASE_URL ?>public/uploads/inventory/<?= htmlspecialchars($photo['file_path']) ?>" target="_blank">
                                            <img src="<?= BASE_URL ?>public/uploads/inventory/<?= htmlspecialchars($photo['file_path']) ?>" 
                                                 class="img-fluid rounded mb-2" style="max-height: 180px; object-fit: cover;">
                                        </a>
                                        <?php if (!empty($photo['caption'])): ?>
                                            <p class="small mb-0 text-muted"><?= htmlspecialchars($photo['caption']) ?></p>
                                        <?php else: ?>
                                            <p class="small mb-0 text-muted fst-italic">No caption</p>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            </div>
        <?php else: ?>
            <div class="card border-0 shadow-sm mb-4">
                <div class="card-body text-center py-4">
                    <div class="text-muted">
                        <i class="fas fa-camera fa-2x mb-3"></i>
                        <p class="mb-0">No photos uploaded for this inventory item.</p>
                        <?php if (RoleHelper::hasPermission('edit_inventory')): ?>
                            <small>Use the edit page to add photos.</small>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        <?php endif; ?>

        <!-- Navigation -->
        <div class="mt-4 pt-3 border-top">
            <div class="d-flex gap-2 flex-wrap">
                <?php if ($from === 'inventory'): ?>
                    <a href="<?= BASE_URL ?>inventory" class="btn btn-outline-secondary">
                        <i class="fas fa-arrow-left me-1"></i>Back to Inventory
                    </a>
                <?php elseif (isset($_SESSION['came_from_receiving_view'])): ?>
                    <a href="<?= BASE_URL ?>receiving/view?id=<?= urlencode($_SESSION['came_from_receiving_view']) ?>" class="btn btn-outline-secondary">
                        <i class="fas fa-arrow-left me-1"></i>Back to Receiving Log
                    </a>
                <?php else: ?>
                    <a href="<?= BASE_URL ?>inventory" class="btn btn-outline-secondary">
                        <i class="fas fa-arrow-left me-1"></i>Back to Inventory
                    </a>
                <?php endif; ?>
                
                <?php if (RoleHelper::hasPermission('add_inventory') && $item['receiving_id']): ?>
                    <a href="<?= BASE_URL ?>inventory/add?receiving_id=<?= urlencode($item['receiving_id']) ?>" 
                       class="btn btn-outline-success" data-permission="add_inventory">
                        <i class="fas fa-plus me-1"></i>Add Another Item
                    </a>
                <?php endif; ?>
            </div>
        </div>
    <?php endif; ?>
</div>

<!-- UPDATED: Delete confirmation script -->
<script>
function confirmDeleteItem(itemId) {
    const confirmed = confirm(
        "Are you sure you want to delete this inventory item?\n\n" +
        "This action cannot be undone.\n\n" +
        "Click OK to proceed with deletion."
    );
    
    if (confirmed) {
        // Check permission before allowing delete
        requirePermission('delete_inventory', function() {
            // Create hidden form and submit
            const form = document.createElement('form');
            form.method = 'POST';
            form.action = '<?= BASE_URL ?>inventory/delete';
            form.style.display = 'none';
            
            const itemIdInput = document.createElement('input');
            itemIdInput.type = 'hidden';
            itemIdInput.name = 'item_id';
            itemIdInput.value = itemId;
            
            const confirmInput = document.createElement('input');
            confirmInput.type = 'hidden';
            confirmInput.name = 'confirm_delete';
            confirmInput.value = '1';
            
            // Add receiving_id if available for proper redirect
            <?php if ($item && $item['receiving_id']): ?>
            const receivingIdInput = document.createElement('input');
            receivingIdInput.type = 'hidden';
            receivingIdInput.name = 'receiving_id';
            receivingIdInput.value = '<?= $item['receiving_id'] ?>';
            form.appendChild(receivingIdInput);
            <?php endif; ?>
            
            form.appendChild(itemIdInput);
            form.appendChild(confirmInput);
            document.body.appendChild(form);
            form.submit();
        });
    }
}
</script>

<!-- UPDATED: Custom CSS for permission elements and responsive design -->
<style>
/* Permission-protected elements styling */
[data-permission].permission-denied {
    opacity: 0.6;
    pointer-events: none;
    position: relative;
}

[data-permission].permission-denied::after {
    content: "\f023";
    font-family: "Font Awesome 5 Free";
    font-weight: 900;
    position: absolute;
    top: 50%;
    right: 8px;
    transform: translateY(-50%);
    color: #dc3545;
    font-size: 12px;
}

/* Expiration badges */
.badge.bg-danger {
    animation: pulse 2s infinite;
}

@keyframes pulse {
    0% { opacity: 1; }
    50% { opacity: 0.5; }
    100% { opacity: 1; }
}

/* Mobile responsiveness */
@media (max-width: 768px) {
    .d-flex.gap-2.flex-wrap {
        gap: 0.5rem !important;
    }
    
    .btn-sm {
        font-size: 0.775rem;
        padding: 0.25rem 0.5rem;
    }
    
    .d-flex.flex-wrap {
        flex-direction: column;
    }
    
    .btn {
        text-align: center;
    }
}

/* Card enhancements */
.card {
    transition: box-shadow 0.3s ease;
}

.card:hover {
    box-shadow: 0 0.125rem 0.5rem rgba(0, 0, 0, 0.15) !important;
}
</style>

<?php include __DIR__ . '/../partials/footer.php'; ?>