<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Require specific permission for creating receiving logs
AuthHelper::requirePermission('create_receiving_logs');

$success = '';
$error = '';
$receiving_id = null;
$organization_id = $_SESSION['organization_id'];

// Fetch existing categories for this organization
$categories = [];
try {
    $stmt = $pdo->prepare("SELECT id, category_name FROM whsale_inventory_pro_categories WHERE organization_id = ? ORDER BY category_name ASC");
    $stmt->execute([$organization_id]);
    $categories = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (Exception $e) {
    error_log("Error fetching categories: " . $e->getMessage());
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $vendor_name = trim($_POST['vendor_name'] ?? '');
    $po_number = trim($_POST['po_number'] ?? '');
    $delivery_date = $_POST['delivery_date'] ?? '';
    $notes = trim($_POST['notes'] ?? '');
    $category_id = $_POST['category_id'] ?? null;
    $new_category = trim($_POST['new_category'] ?? '');
    $user_id = AuthHelper::getUserId();

    if ($vendor_name && $delivery_date) {
        try {
            $pdo->beginTransaction();

            // Handle category logic
            $final_category_id = null;
            
            if (!empty($new_category)) {
                // User wants to create a new category
                $stmt = $pdo->prepare("INSERT IGNORE INTO whsale_inventory_pro_categories (organization_id, category_name) VALUES (?, ?)");
                $stmt->execute([$organization_id, $new_category]);
                
                // Get the category ID (whether newly created or existing)
                $stmt = $pdo->prepare("SELECT id FROM whsale_inventory_pro_categories WHERE organization_id = ? AND category_name = ?");
                $stmt->execute([$organization_id, $new_category]);
                $final_category_id = $stmt->fetchColumn();
            } elseif (!empty($category_id) && $category_id !== '') {
                // User selected an existing category
                $final_category_id = $category_id;
            }
            // If both are empty, $final_category_id remains null (no category)

            // Create receiving log with category and organization_id
            $stmt = $pdo->prepare("CALL whsale_inventory_pro_create_receiving_log(?, ?, ?, ?, ?, ?, ?, ?)");
            $stmt->execute([$vendor_name, $po_number, $delivery_date, $notes, $user_id, $user_id, $final_category_id, $organization_id]);
            $receiving_id = $pdo->query("SELECT LAST_INSERT_ID()")->fetchColumn();
            $stmt->closeCursor();

            // Handle photo uploads (only if user has permission)
            if (!empty($_FILES['photos']['name'][0]) && RoleHelper::hasPermission('upload_receiving_photos')) {
                $upload_dir = __DIR__ . '/../../public/uploads/receiving/';
                if (!is_dir($upload_dir)) mkdir($upload_dir, 0755, true);

                foreach ($_FILES['photos']['name'] as $index => $name) {
                    $tmp_name = $_FILES['photos']['tmp_name'][$index];
                    $errorCode = $_FILES['photos']['error'][$index];
                    $extension = strtolower(pathinfo($name, PATHINFO_EXTENSION));
                    $allowed = ['jpg', 'jpeg', 'png', 'gif', 'webp'];

                    if ($errorCode === UPLOAD_ERR_OK && in_array($extension, $allowed)) {
                        $filename = uniqid('receiving_') . '.' . $extension;
                        $filepath = $upload_dir . $filename;
                        if (move_uploaded_file($tmp_name, $filepath)) {
                            $stmt = $pdo->prepare("INSERT INTO whsale_inventory_pro_receiving_photos (receiving_id, file_path, uploaded_by) VALUES (?, ?, ?)");
                            $stmt->execute([$receiving_id, $filename, $user_id]);
                        }
                    }
                }
            }

            $pdo->commit();
            header("Location: " . BASE_URL . "receiving/confirmation?receiving_id=" . $receiving_id);
            exit;
        } catch (Exception $e) {
            $pdo->rollback();
            $error = "Database error: " . $e->getMessage();
        }
    } else {
        $error = "Vendor and delivery date are required.";
    }
}
?>

<?php include __DIR__ . '/../partials/head.php'; ?>

<div class="container mt-4 mb-5">
    <div class="row justify-content-center">
        <div class="col-12 col-md-10 col-lg-7">
            <div class="d-flex align-items-center mb-3">
                <h4 class="mb-0">Add New Receiving Log</h4>
                <div class="ms-auto">
                    <?= RoleHelper::getRoleBadge() ?>
                </div>
            </div>

            <!-- UPDATED: Add permission info card -->
            <div class="alert alert-info mb-4">
                <div class="d-flex align-items-center">
                    <i class="fas fa-info-circle me-2"></i>
                    <div>
                        <strong>Creating a Receiving Log:</strong>
                        <p class="mb-0 mt-1">Document deliveries to track what was received, when, and from which vendor. You can add inventory items to this log after creation.</p>
                    </div>
                </div>
            </div>

            <?php if ($success): ?>
                <div class="alert alert-success">
                    <i class="fas fa-check-circle me-2"></i>
                    <?= htmlspecialchars($success) ?>
                </div>
            <?php endif; ?>
            <?php if ($error): ?>
                <div class="alert alert-danger">
                    <i class="fas fa-exclamation-circle me-2"></i>
                    <?= htmlspecialchars($error) ?>
                </div>
            <?php endif; ?>

            <form method="POST" enctype="multipart/form-data" class="card shadow-sm p-4 bg-white border-0" onsubmit="showSpinner()">
                <div class="mb-3">
                    <label class="form-label">Vendor Name <span class="text-danger">*</span></label>
                    <input type="text" name="vendor_name" class="form-control" required 
                           value="<?= htmlspecialchars($_POST['vendor_name'] ?? '') ?>"
                           placeholder="Enter the vendor or supplier name">
                </div>
                
                <div class="mb-3">
                    <label class="form-label">PO Number</label>
                    <input type="text" name="po_number" class="form-control" 
                           value="<?= htmlspecialchars($_POST['po_number'] ?? '') ?>"
                           placeholder="Purchase order number (optional)">
                </div>
                
                <div class="mb-3">
                    <label class="form-label">Category</label>
                    <div class="category-selector">
                        <!-- Existing Category Dropdown -->
                        <select name="category_id" id="categorySelect" class="form-select mb-2">
                            <option value="">Select existing category (optional)</option>
                            <?php foreach ($categories as $category): ?>
                                <option value="<?= $category['id'] ?>" <?= (($_POST['category_id'] ?? '') == $category['id']) ? 'selected' : '' ?>>
                                    <?= htmlspecialchars($category['category_name']) ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                        
                        <!-- OR divider -->
                        <div class="text-center text-muted small mb-2">
                            <span class="px-2 bg-white">OR</span>
                            <hr class="mt-0" style="margin-top: -12px; z-index: -1;">
                        </div>
                        
                        <!-- New Category Input -->
                        <div class="input-group">
                            <input type="text" name="new_category" id="newCategoryInput" class="form-control" 
                                   placeholder="Create new category..." maxlength="100"
                                   value="<?= htmlspecialchars($_POST['new_category'] ?? '') ?>">
                            <button type="button" class="btn btn-outline-secondary" id="clearCategoryBtn" 
                                    onclick="clearCategorySelection()" title="Clear selection">
                                <i class="fas fa-times"></i>
                            </button>
                        </div>
                        
                        <div class="form-text">
                            <i class="fas fa-info-circle me-1"></i>
                            Select from existing categories or type a new one. Categories are shared across your organization.
                        </div>
                    </div>
                </div>
                
                <div class="mb-3">
                    <label class="form-label">Delivery Date <span class="text-danger">*</span></label>
                    <input type="date" name="delivery_date" class="form-control" required 
                           value="<?= htmlspecialchars($_POST['delivery_date'] ?? '') ?>">
                    <div class="form-text">
                        <i class="fas fa-calendar me-1"></i>
                        When was this delivery received?
                    </div>
                </div>
                
                <div class="mb-3">
                    <label class="form-label">Notes</label>
                    <textarea name="notes" class="form-control" rows="3" 
                              placeholder="Any additional information about this delivery..."><?= htmlspecialchars($_POST['notes'] ?? '') ?></textarea>
                </div>
                
                <!-- UPDATED: Photo upload section with permission check -->
                <?php if (RoleHelper::hasPermission('upload_receiving_photos')): ?>
                    <div class="mb-3">
                        <label class="form-label">Upload Photos (Optional)</label>
                        <input type="file" name="photos[]" class="form-control" multiple accept="image/*" onchange="previewImages(event)">
                        <div class="form-text">
                            <i class="fas fa-camera me-1"></i>
                            Document the delivery with photos
                        </div>
                        <div id="imagePreview" class="d-flex flex-wrap gap-2 mt-2"></div>
                    </div>
                <?php else: ?>
                    <div class="mb-3">
                        <div class="alert alert-warning">
                            <i class="fas fa-camera me-2"></i>
                            <strong>Photo Upload Restricted:</strong> Contact your administrator to get permission to upload photos with receiving logs.
                        </div>
                    </div>
                <?php endif; ?>
                
                <div class="d-flex gap-2 flex-wrap">
                    <button type="submit" class="btn btn-dark">
                        <i class="fas fa-save me-1"></i>Create Receiving Log
                    </button>
                    <a href="<?= BASE_URL ?>receiving" class="btn btn-outline-secondary">
                        <i class="fas fa-arrow-left me-1"></i>Back to Receiving List
                    </a>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Spinner Overlay -->
<div id="spinnerOverlay" class="position-fixed top-0 start-0 w-100 h-100 d-none" style="background-color: rgba(255, 255, 255, 0.75); z-index: 1050;">
  <div class="d-flex justify-content-center align-items-center h-100">
    <div class="text-center">
        <div class="spinner-border text-dark mb-3" role="status" style="width: 3rem; height: 3rem;">
            <span class="visually-hidden">Creating...</span>
        </div>
        <div class="fw-medium text-dark">Creating receiving log... This may take a few seconds, please wait.</div>
    </div>
  </div>
</div>

<!-- Custom CSS for Category Selector -->
<style>
.category-selector {
    position: relative;
}

.category-selector .form-select:focus,
.category-selector .form-control:focus {
    border-color: #0d6efd;
    box-shadow: 0 0 0 0.2rem rgba(13, 110, 253, 0.25);
}

.category-selector hr {
    position: relative;
    border-color: #dee2e6;
}

.category-selector .text-muted span {
    position: relative;
    z-index: 1;
}

#clearCategoryBtn {
    border-left: none;
}

.input-group .form-control:focus + .btn {
    border-color: #0d6efd;
    box-shadow: 0 0 0 0.2rem rgba(13, 110, 253, 0.25);
}

/* Alert styling */
.alert-info {
    border-left: 4px solid #0dcaf0;
}

.alert-warning {
    border-left: 4px solid #ffc107;
}

/* Mobile responsiveness */
@media (max-width: 768px) {
    .d-flex.gap-2.flex-wrap {
        flex-direction: column;
    }
    
    .btn {
        text-align: center;
    }
}
</style>

<!-- Enhanced JavaScript -->
<script>
// Show spinner on form submission
function showSpinner() {
    document.getElementById('spinnerOverlay').classList.remove('d-none');
}

// Handle category selection logic
document.addEventListener('DOMContentLoaded', function() {
    const categorySelect = document.getElementById('categorySelect');
    const newCategoryInput = document.getElementById('newCategoryInput');
    
    // When user selects an existing category, clear the new category input
    categorySelect.addEventListener('change', function() {
        if (this.value) {
            newCategoryInput.value = '';
        }
    });
    
    // When user types in new category, clear the existing category selection
    newCategoryInput.addEventListener('input', function() {
        if (this.value) {
            categorySelect.value = '';
        }
    });
});

// Clear both category selections
function clearCategorySelection() {
    document.getElementById('categorySelect').value = '';
    document.getElementById('newCategoryInput').value = '';
}

// Preview uploaded images
function previewImages(event) {
    const preview = document.getElementById('imagePreview');
    if (!preview) return; // Check if preview element exists
    
    preview.innerHTML = '';
    const files = event.target.files;
    Array.from(files).forEach(file => {
        const reader = new FileReader();
        reader.onload = e => {
            const img = document.createElement('img');
            img.src = e.target.result;
            img.className = 'img-thumbnail';
            img.style.width = '100px';
            img.style.height = '100px';
            img.style.objectFit = 'cover';
            preview.appendChild(img);
        };
        reader.readAsDataURL(file);
    });
}
</script>

<!-- Mobile Camera Warning -->
<?php if (RoleHelper::hasPermission('upload_receiving_photos')): ?>
<div id="camera-warning" class="alert alert-warning mt-3 d-none">
    <i class="fas fa-mobile-alt me-2"></i>
    <strong>Mobile Tip:</strong> Taking photos with the camera allows only one image upload at a time. To upload multiple images at once, please select them from your photo library.
</div>
<script>
document.addEventListener('DOMContentLoaded', function () {
    const input = document.querySelector('input[type="file"][multiple]');
    const warning = document.getElementById('camera-warning');

    if (!input || !warning) return;

    const isMobile = /iPhone|iPad|iPod|Android/i.test(navigator.userAgent);
    if (isMobile) warning.classList.remove('d-none');
});
</script>
<?php endif; ?>

<?php include __DIR__ . '/../partials/footer.php'; ?>