<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Basic login required for viewing (all users can view)
AuthHelper::requireLogin();

$user_id = AuthHelper::getUserId();
$organization_id = $_SESSION['organization_id'];
$receivingLogs = [];

// Fetch categories for filter dropdown
$categories = [];
try {
    $stmt = $pdo->prepare("SELECT id, category_name FROM whsale_inventory_pro_categories WHERE organization_id = ? ORDER BY category_name ASC");
    $stmt->execute([$organization_id]);
    $categories = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (Exception $e) {
    error_log("Error fetching categories: " . $e->getMessage());
}

try {
    // Updated query to include category information
    $stmt = $pdo->prepare("
    SELECT r.*, c.category_name 
    FROM whsale_inventory_pro_receiving_log r
    LEFT JOIN whsale_inventory_pro_categories c ON r.category_id = c.id
    WHERE r.organization_id = ? AND r.is_active = 1
    ORDER BY r.created_at DESC
");
    $stmt->execute([$organization_id]);
    $receivingLogs = $stmt->fetchAll();

    // Apply filters
    $search = trim($_GET['search'] ?? '');
    $deliveryDate = $_GET['delivery_date'] ?? '';
    $categoryFilter = $_GET['category_id'] ?? '';

    $receivingLogs = array_filter($receivingLogs, function ($log) use ($search, $deliveryDate, $categoryFilter) {
        $match = true;

        if ($search) {
            $match &= stripos($log['vendor_name'], $search) !== false || 
                     stripos($log['po_number'], $search) !== false ||
                     stripos($log['category_name'], $search) !== false;
        }

        if ($deliveryDate) {
            $match &= date('Y-m-d', strtotime($log['delivery_date'])) === $deliveryDate;
        }

        if ($categoryFilter) {
            if ($categoryFilter === 'uncategorized') {
                $match &= empty($log['category_id']);
            } else {
                $match &= $log['category_id'] == $categoryFilter;
            }
        }

        return $match;
    });

    $stmt->closeCursor();
} catch (Exception $e) {
    $error = "Unable to load receiving logs: " . $e->getMessage();
}
?>

<?php include __DIR__ . '/../partials/head.php'; ?>

<div class="container mt-4 mb-5">
    <div class="d-flex justify-content-between align-items-center mb-3">
        <h4>Receiving Logs</h4>
        <!-- UPDATED: Add permission check for create button -->
        <?php if (RoleHelper::hasPermission('create_receiving_logs')): ?>
            <a href="<?= BASE_URL ?>receiving/add" class="btn btn-dark btn-sm" data-permission="create_receiving_logs">
                <i class="fas fa-plus me-1"></i>Add New
            </a>
        <?php else: ?>
            <button class="btn btn-dark btn-sm opacity-50" disabled title="You need permission to create receiving logs" data-permission="create_receiving_logs">
                <i class="fas fa-plus me-1"></i>Add New
            </button>
        <?php endif; ?>
    </div>

    <!-- Enhanced Filter Form with Better Responsive Layout -->
    <form method="GET" class="card p-3 mb-3 shadow-sm">
        <div class="row g-3">
            <!-- First Row: Search Fields -->
            <div class="col-12 col-md-6 col-lg-4">
                <label for="search" class="form-label">Text Search</label>
                <input type="text" name="search" value="<?= htmlspecialchars($_GET['search'] ?? '') ?>" 
                       class="form-control" placeholder="Search Vendor, PO, or Category">
            </div>
            
            <div class="col-12 col-md-6 col-lg-4">
                <label for="delivery_date" class="form-label">Delivery Date</label>
                <input type="date" id="delivery_date" name="delivery_date" 
                       value="<?= htmlspecialchars($_GET['delivery_date'] ?? '') ?>" class="form-control">
            </div>
            
            <div class="col-12 col-md-6 col-lg-4">
                <label for="category_id" class="form-label">Category</label>
                <select name="category_id" id="category_id" class="form-select">
                    <option value="">All Categories</option>
                    <option value="uncategorized" <?= ($_GET['category_id'] ?? '') === 'uncategorized' ? 'selected' : '' ?>>
                        Uncategorized
                    </option>
                    <?php foreach ($categories as $category): ?>
                        <option value="<?= $category['id'] ?>" <?= (($_GET['category_id'] ?? '') == $category['id']) ? 'selected' : '' ?>>
                            <?= htmlspecialchars($category['category_name']) ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            
            <!-- Second Row: Action Buttons -->
            <div class="col-12">
                <div class="d-flex gap-2 justify-content-end flex-wrap">
                    <button class="btn btn-outline-secondary" type="submit">
                        <i class="fas fa-filter me-1"></i>Apply Filters
                    </button>
                    <a href="<?= BASE_URL ?>receiving" class="btn btn-outline-danger">
                        <i class="fas fa-times me-1"></i>Clear All
                    </a>
                </div>
            </div>
        </div>
    </form>

    <?php if (!empty($error)): ?>
        <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
    <?php elseif (empty($receivingLogs)): ?>
        <div class="alert alert-warning">
            <i class="fas fa-info-circle me-2"></i>
            No receiving logs found. <?= !empty($_GET['search']) || !empty($_GET['delivery_date']) || !empty($_GET['category_id']) ? 'Try adjusting your filters.' : '' ?>
            <!-- UPDATED: Show helpful message based on permissions -->
            <?php if (empty($_GET['search']) && empty($_GET['delivery_date']) && empty($_GET['category_id'])): ?>
                <?php if (RoleHelper::hasPermission('create_receiving_logs')): ?>
                    <a href="<?= BASE_URL ?>receiving/add" class="btn btn-sm btn-outline-primary ms-2">
                        <i class="fas fa-plus me-1"></i>Create your first receiving log
                    </a>
                <?php else: ?>
                    <br><small class="text-muted">Contact your administrator to get permission to create receiving logs.</small>
                <?php endif; ?>
            <?php endif; ?>
        </div>
    <?php else: ?>

        <!-- Results Summary -->
        <div class="mb-3">
            <small class="text-muted">
                <i class="fas fa-list me-1"></i>
                Showing <?= count($receivingLogs) ?> receiving log<?= count($receivingLogs) !== 1 ? 's' : '' ?>
                <?php if (!empty($_GET['search']) || !empty($_GET['delivery_date']) || !empty($_GET['category_id'])): ?>
                    (filtered)
                <?php endif; ?>
            </small>
        </div>

        <!-- Desktop Table View -->
        <div class="table-responsive d-none d-lg-block">
            <table class="table table-bordered table-hover table-sm bg-white">
                <thead class="table-light">
                    <tr>
                        <th>Vendor</th>
                        <th>Category</th>
                        <th>PO Number</th>
                        <th>Delivery Date</th>
                        <th>Notes</th>
                        <th>Created</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($receivingLogs as $log): ?>
                        <tr>
                            <td><?= htmlspecialchars($log['vendor_name']) ?></td>
                            <td>
                                <?php if (!empty($log['category_name'])): ?>
                                    <span class="badge bg-secondary">
                                        <?= htmlspecialchars($log['category_name']) ?>
                                    </span>
                                <?php else: ?>
                                    <span class="text-muted small">Uncategorized</span>
                                <?php endif; ?>
                            </td>
                            <td><?= htmlspecialchars($log['po_number']) ?></td>
                            <td><?= date('M d, Y', strtotime($log['delivery_date'])) ?></td>
                            <td><?= nl2br(htmlspecialchars(substr($log['notes'], 0, 100))) ?><?= strlen($log['notes']) > 100 ? '...' : '' ?></td>
                            <td><?= date('M d, Y', strtotime($log['created_at'])) ?></td>
                            <td>
                                <!-- UPDATED: Action buttons with permission checks -->
                                <div class="d-flex gap-1 flex-wrap">
                                    <a href="<?= BASE_URL ?>receiving/view?id=<?= urlencode($log['id']) ?>" 
                                       class="btn btn-sm btn-outline-primary">
                                        <i class="fas fa-eye me-1"></i>View
                                    </a>
                                    
                                    <?php if (RoleHelper::hasPermission('edit_receiving_logs')): ?>
                                        <a href="<?= BASE_URL ?>receiving/edit?id=<?= urlencode($log['id']) ?>" 
                                           class="btn btn-sm btn-outline-secondary" data-permission="edit_receiving_logs">
                                            <i class="fas fa-edit me-1"></i>Edit
                                        </a>
                                    <?php endif; ?>
                                    
                                    <?php if (RoleHelper::hasPermission('delete_receiving_logs')): ?>
                                        <button class="btn btn-sm btn-outline-danger" 
                                                onclick="confirmDelete(<?= $log['id'] ?>)" 
                                                data-permission="delete_receiving_logs">
                                            <i class="fas fa-trash me-1"></i>Delete
                                        </button>
                                    <?php endif; ?>
                                </div>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>

        <!-- Mobile Card View -->
        <div class="d-block d-lg-none">
            <?php foreach ($receivingLogs as $log): ?>
                <div class="card mb-3 shadow-sm">
                    <div class="card-body">
                        <div class="d-flex justify-content-between align-items-start mb-2">
                            <h5 class="card-title mb-0"><?= htmlspecialchars($log['vendor_name']) ?></h5>
                            <?php if (!empty($log['category_name'])): ?>
                                <span class="badge bg-secondary">
                                    <?= htmlspecialchars($log['category_name']) ?>
                                </span>
                            <?php else: ?>
                                <span class="badge bg-light text-dark">Uncategorized</span>
                            <?php endif; ?>
                        </div>
                        <p class="mb-1"><strong>PO #:</strong> <?= htmlspecialchars($log['po_number']) ?></p>
                        <p class="mb-1"><strong>Delivery:</strong> <?= date('M d, Y', strtotime($log['delivery_date'])) ?></p>
                        <?php if (!empty($log['notes'])): ?>
                            <p class="mb-1"><strong>Notes:</strong><br><?= nl2br(htmlspecialchars($log['notes'])) ?></p>
                        <?php endif; ?>
                        <p class="mb-3"><strong>Created:</strong> <?= date('M d, Y', strtotime($log['created_at'])) ?></p>
                        
                        <!-- UPDATED: Mobile action buttons with permission checks -->
                        <div class="d-flex gap-2 flex-wrap">
                            <a href="<?= BASE_URL ?>receiving/view?id=<?= urlencode($log['id']) ?>" 
                               class="btn btn-sm btn-outline-primary flex-fill">
                                <iclass="fas fa-eye me-1"></i>View
                            </a>
                            
                            <?php if (RoleHelper::hasPermission('edit_receiving_logs')): ?>
                                <a href="<?= BASE_URL ?>receiving/edit?id=<?= urlencode($log['id']) ?>" 
                                   class="btn btn-sm btn-outline-secondary flex-fill" data-permission="edit_receiving_logs">
                                    <iclass="fas fa-edit me-1"></i>Edit
                                </a>
                            <?php endif; ?>
                            
                            <?php if (RoleHelper::hasPermission('delete_receiving_logs')): ?>
                                <button class="btn btn-sm btn-outline-danger flex-fill" 
                                        onclick="confirmDelete(<?= $log['id'] ?>)" 
                                        data-permission="delete_receiving_logs">
                                    <iclass="fas fa-trash me-1"></i>Delete
                                </button>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
    <?php endif; ?>
</div>

<!-- UPDATED: Add delete confirmation script with permission checking -->
<script>
function confirmDelete(logId) {
    if (confirm('Are you sure you want to delete this receiving log? This action cannot be undone.')) {
        // Check permission before allowing delete
        requirePermission('delete_receiving_logs', function() {
            // Create hidden form and submit
            const form = document.createElement('form');
            form.method = 'POST';
            form.action = '<?= BASE_URL ?>receiving/delete';
            form.style.display = 'none';
            
            const idInput = document.createElement('input');
            idInput.type = 'hidden';
            idInput.name = 'id';
            idInput.value = logId;
            
            const confirmInput = document.createElement('input');
            confirmInput.type = 'hidden';
            confirmInput.name = 'confirm_delete';
            confirmInput.value = '1';
            
            form.appendChild(idInput);
            form.appendChild(confirmInput);
            document.body.appendChild(form);
            form.submit();
        });
    }
}
</script>

<!-- UPDATED: Custom CSS for permission-disabled elements -->
<style>
.btn.opacity-50 {
    opacity: 0.5 !important;
    cursor: not-allowed;
}

.btn.opacity-50:hover {
    opacity: 0.5 !important;
}

/* Permission-protected elements styling */
[data-permission].permission-denied {
    opacity: 0.6;
    pointer-events: none;
    position: relative;
}

[data-permission].permission-denied::after {
    content: "\f023";
    font-family: "Font Awesome 5 Free";
    font-weight: 900;
    position: absolute;
    top: 50%;
    right: 8px;
    transform: translateY(-50%);
    color: #dc3545;
    font-size: 12px;
}

/* Mobile responsiveness improvements */
@media (max-width: 768px) {
    .d-flex.gap-1 {
        gap: 0.25rem !important;
    }
    
    .btn-sm {
        font-size: 0.775rem;
        padding: 0.25rem 0.5rem;
    }
}

/* Desktop action buttons */
@media (min-width: 992px) {
    .table td .d-flex {
        justify-content: flex-start;
    }
}
</style>

<?php include __DIR__ . '/../partials/footer.php'; ?>