<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Require permission for storefront access
AuthHelper::requirePermission('publish_to_storefront');

$receiving_id = $_GET['receiving_id'] ?? null;
$organization_id = $_SESSION['organization_id'] ?? null;
$organization_slug = $_SESSION['organization_slug'] ?? null;

if (!$receiving_id || !is_numeric($receiving_id)) {
    header("Location: " . BASE_URL . "dashboard");
    exit;
}

// UPDATED: Enhanced error handling for missing organization data
if (!$organization_id || !$organization_slug) {
    $error = "Organization information is missing. Please contact support.";
} else {
    try {
        // UPDATED: Enhanced security - verify listing belongs to user's organization and get product ID
        $stmt = $pdo->prepare("
            SELECT 
                s.id as product_id, s.title, s.description, s.created_at, 
                r.vendor_name, r.organization_id
            FROM whsale_inventory_pro_storefront_products s
            JOIN whsale_inventory_pro_receiving_log r ON s.receiving_id = r.id
            WHERE s.receiving_id = ? AND r.organization_id = ?
            ORDER BY s.created_at DESC
            LIMIT 1
        ");
        $stmt->execute([$receiving_id, $organization_id]);
        $listing = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if (!$listing) {
            throw new Exception("Listing not found or you don't have permission to view it.");
        }
        
    } catch (Exception $e) {
        $error = $e->getMessage();
    }
}
?>

<?php include __DIR__ . '/../partials/head.php'; ?>

<div class="container mt-5 mb-5">
    <div class="row justify-content-center">
        <div class="col-12 col-lg-8">
            <?php if (!empty($error)): ?>
                <div class="alert alert-danger">
                    <i class="fas fa-exclamation-circle me-2"></i>
                    <?= htmlspecialchars($error) ?>
                </div>
                <div class="text-center mt-4">
                    <a href="<?= BASE_URL ?>dashboard" class="btn btn-outline-secondary">
                        <i class="fas fa-arrow-left me-1"></i>Back to Dashboard
                    </a>
                </div>
            <?php else: ?>
                <div class="card shadow-sm border-0">
                    <div class="card-header bg-success text-white text-center">
                        <h4 class="mb-0">
                            <i class="fas fa-check-circle me-2"></i>Listing Published Successfully!
                        </h4>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-8 mx-auto text-center">
                                <div class="mb-4">
                                    <h5 class="text-success mb-3">Your product is now live on your store!</h5>
                                    <p class="text-muted">Customers can now view and inquire about this product.</p>
                                </div>
                                
                                <!-- Listing Details -->
                                <div class="card bg-light mb-4">
                                    <div class="card-body">
                                        <h6 class="card-title text-start">
                                            <iclass="fas fa-info-circle me-2"></i>Listing Details
                                        </h6>
                                        <div class="text-start">
                                            <p class="mb-2"><strong>Vendor:</strong> <?= htmlspecialchars($listing['vendor_name']) ?></p>
                                            <p class="mb-2"><strong>Title:</strong> <?= htmlspecialchars($listing['title']) ?></p>
                                            <p class="mb-2"><strong>Description:</strong><br><?= nl2br(htmlspecialchars($listing['description'])) ?></p>
                                            <p class="mb-0"><strong>Published:</strong> <?= date('M d, Y h:i A', strtotime($listing['created_at'])) ?></p>
                                        </div>
                                    </div>
                                </div>
                                
                                <!-- Action Buttons -->
                                <div class="d-grid gap-2 d-md-flex justify-content-md-center">
                                    <!-- UPDATED: Changed to Edit Product Details button -->
                                    <?php if (RoleHelper::hasPermission('edit_storefront_listings')): ?>
                                        <a href="<?= BASE_URL ?>storefront/manage/edit?id=<?= urlencode($listing['product_id']) ?>" 
                                           class="btn btn-outline-secondary" data-permission="edit_storefront_listings">
                                            <i class="fas fa-edit me-1"></i>Edit Product Details
                                        </a>
                                    <?php endif; ?>
                                    
                                    <!-- UPDATED: Use organization_slug from session -->
                                    <a href="<?= BASE_URL ?>storefront/<?= urlencode($organization_slug) ?>" 
                                       class="btn btn-primary" target="_blank">
                                        <i class="fas fa-external-link-alt me-1"></i>View My Store
                                    </a>
                                    
                                    <!-- UPDATED: Link to manage all listings -->
                                    <a href="<?= BASE_URL ?>storefront/manage" 
                                       class="btn btn-outline-success">
                                        <i class="fas fa-cog me-1"></i>Manage All Listings
                                    </a>
                                </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            <?php endif; ?>
        </div>
    </div>
</div>

<!-- UPDATED: Custom CSS for confirmation page -->
<style>
.card-header.bg-success {
    background-color: #28a745 !important;
}

.bg-info.bg-opacity-10 {
    background-color: rgba(13, 202, 240, 0.1) !important;
}

.card:hover {
    transform: translateY(-2px);
    box-shadow: 0 4px 12px rgba(0, 0, 0, 0.15);
    transition: all 0.2s ease;
}

/* Mobile responsiveness */
@media (max-width: 768px) {
    .d-grid.gap-2.d-md-flex {
        gap: 0.75rem !important;
    }
    
    .btn {
        padding: 0.5rem 1rem;
        font-size: 0.9rem;
    }
}

/* Button improvements */
.btn:hover {
    transform: translateY(-1px);
    transition: all 0.2s ease;
}

.btn-primary {
    box-shadow: 0 2px 4px rgba(0, 123, 255, 0.3);
}

.btn-primary:hover {
    box-shadow: 0 4px 8px rgba(0, 123, 255, 0.4);
}
</style>

<?php include __DIR__ . '/../partials/footer.php'; ?>