<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Basic login required, specific permissions checked below
AuthHelper::requireLogin();

$user_id = $_SESSION['user_id'] ?? null;
$organization_id = $_SESSION['organization_id'] ?? null;
$product_id = $_POST['product_id'] ?? null;
$action = $_POST['action'] ?? 'delete';

if (!$user_id || !$organization_id || !$product_id || !is_numeric($product_id)) {
    $_SESSION['error'] = "Invalid request parameters.";
    header("Location: " . BASE_URL . "storefront/manage");
    exit;
}

try {
    // UPDATED: Enhanced security - verify product belongs to user's organization
    $stmt = $pdo->prepare("
        SELECT sp.id, sp.title, sp.is_active 
        FROM whsale_inventory_pro_storefront_products sp
        WHERE sp.id = ? AND sp.organization_id = ?
    ");
    $stmt->execute([$product_id, $organization_id]);
    $product = $stmt->fetch();
    
    if (!$product) {
        throw new Exception("Product not found or you don't have permission to modify it.");
    }
    
    // UPDATED: Permission checks based on action
    if ($action === 'reactivate') {
        // UPDATED: Require permission to edit storefront listings
        AuthHelper::requirePermission('edit_storefront_listings');
        
        $stmt = $pdo->prepare("
            UPDATE whsale_inventory_pro_storefront_products 
            SET is_active = 1 
            WHERE id = ? AND organization_id = ?
        ");
        $stmt->execute([$product_id, $organization_id]);
        
        $_SESSION['success'] = "Product '" . htmlspecialchars($product['title']) . "' has been reactivated successfully.";
        
    } elseif ($action === 'hard_delete') {
        // UPDATED: Require permission to remove storefront listings
        AuthHelper::requirePermission('remove_storefront_listings');
        
        // Permanent deletion with organization verification
        $stmt = $pdo->prepare("
            DELETE FROM whsale_inventory_pro_storefront_products 
            WHERE id = ? AND organization_id = ?
        ");
        $stmt->execute([$product_id, $organization_id]);
        
        if ($stmt->rowCount() > 0) {
            $_SESSION['success'] = "Product '" . htmlspecialchars($product['title']) . "' has been permanently deleted.";
        } else {
            throw new Exception("Failed to delete product. It may have already been removed.");
        }
        
    } else {
        // Default: Soft delete (deactivate)
        // UPDATED: Require permission to remove storefront listings
        AuthHelper::requirePermission('remove_storefront_listings');
        
        $stmt = $pdo->prepare("
            UPDATE whsale_inventory_pro_storefront_products 
            SET is_active = 0 
            WHERE id = ? AND organization_id = ?
        ");
        $stmt->execute([$product_id, $organization_id]);
        
        if ($stmt->rowCount() > 0) {
            $_SESSION['success'] = "Product '" . htmlspecialchars($product['title']) . "' has been removed from active listings.";
        } else {
            throw new Exception("Failed to remove product from active listings.");
        }
    }

} catch (Exception $e) {
    error_log("Storefront delete error (user $user_id, org $organization_id, product $product_id, action $action): " . $e->getMessage());
    
    // Handle permission errors specifically
    if (strpos($e->getMessage(), "permission") !== false) {
        $_SESSION['error'] = "You don't have permission to perform this action.";
    } else {
        $_SESSION['error'] = "An error occurred: " . $e->getMessage();
    }
}

header("Location: " . BASE_URL . "storefront/manage");
exit;
?>