<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Add comprehensive error logging
error_log("=== STOREFRONT UPDATE DEBUG START ===");
error_log("Request Method: " . $_SERVER['REQUEST_METHOD']);
error_log("POST Data: " . print_r($_POST, true));
error_log("Session Data: " . print_r($_SESSION, true));

// UPDATED: Require specific permission for editing storefront listings
AuthHelper::requirePermission('edit_storefront_listings');

if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    error_log("ERROR: Not a POST request, redirecting to manage");
    header("Location: " . BASE_URL . "storefront/manage");
    exit;
}

$product_id = $_POST['product_id'] ?? null;
$title = trim($_POST['title'] ?? '');
$description = trim($_POST['description'] ?? '');
$listed_price = $_POST['listed_price'] ?? null;
$is_active = isset($_POST['is_active']) ? 1 : 0;
$category_id = $_POST['category_id'] ?? null;
$new_category = trim($_POST['new_category'] ?? '');

// UPDATED: Handle payment fields
$payment_link = !empty($_POST['payment_link']) ? trim($_POST['payment_link']) : null;
$payment_type = !empty($_POST['payment_type']) ? $_POST['payment_type'] : null;

$organization_id = $_SESSION['organization_id'];

// Log all parsed values
error_log("Parsed Values:");
error_log("- product_id: " . var_export($product_id, true));
error_log("- title: " . var_export($title, true));
error_log("- description: " . var_export($description, true));
error_log("- listed_price: " . var_export($listed_price, true));
error_log("- is_active: " . var_export($is_active, true));
error_log("- category_id: " . var_export($category_id, true));
error_log("- new_category: " . var_export($new_category, true));
error_log("- payment_link: " . var_export($payment_link, true));
error_log("- payment_type: " . var_export($payment_type, true));
error_log("- organization_id: " . var_export($organization_id, true));

if (!$product_id || !$title || !$description) {
    error_log("ERROR: Missing required fields - product_id: $product_id, title: '$title', description: '$description'");
    $_SESSION['error'] = "Missing required fields.";
    header("Location: " . BASE_URL . "storefront/manage");
    exit;
}

// UPDATED: Validate payment link if provided (only if user has permission)
$hasPaymentPermission = RoleHelper::hasPermission('manage_payment_links');
error_log("User has payment permission: " . var_export($hasPaymentPermission, true));

if ($payment_link && $hasPaymentPermission) {
    error_log("Validating payment link: " . $payment_link);
    if (!filter_var($payment_link, FILTER_VALIDATE_URL)) {
        error_log("ERROR: Invalid payment link URL format");
        $_SESSION['error'] = 'Invalid payment link URL format.';
        header("Location: " . BASE_URL . "storefront/manage/edit?id=" . urlencode($product_id));
        exit;
    } elseif (substr($payment_link, 0, 8) !== 'https://') {
        error_log("ERROR: Payment link must use HTTPS");
        $_SESSION['error'] = 'Payment links must use HTTPS for security.';
        header("Location: " . BASE_URL . "storefront/manage/edit?id=" . urlencode($product_id));
        exit;
    }
    error_log("Payment link validation passed");
} elseif ($payment_link && !$hasPaymentPermission) {
    error_log("WARNING: User lacks payment permission, clearing payment fields");
    // Clear payment fields if user doesn't have permission
    $payment_link = null;
    $payment_type = null;
}

try {
    error_log("Starting database transaction");
    $pdo->beginTransaction();
    
    // Verify the product belongs to this organization
    error_log("Verifying product ownership for product_id: $product_id, organization_id: $organization_id");
    $stmt = $pdo->prepare("SELECT id FROM whsale_inventory_pro_storefront_products WHERE id = ? AND organization_id = ?");
    $stmt->execute([$product_id, $organization_id]);
    $productExists = $stmt->fetch();
    error_log("Product exists check result: " . var_export($productExists, true));
    
    if (!$productExists) {
        throw new Exception("Product not found or unauthorized access.");
    }
    
    // Handle category logic
    $final_category_id = null;
    error_log("Processing category logic...");
    
    if (!empty($new_category)) {
        error_log("Creating new category: " . $new_category);
        // User wants to create a new category
        $stmt = $pdo->prepare("INSERT IGNORE INTO whsale_inventory_pro_categories (organization_id, category_name) VALUES (?, ?)");
        $stmt->execute([$organization_id, $new_category]);
        error_log("Insert result - affected rows: " . $stmt->rowCount());
        
        // Get the category ID (whether newly created or existing)
        $stmt = $pdo->prepare("SELECT id FROM whsale_inventory_pro_categories WHERE organization_id = ? AND category_name = ?");
        $stmt->execute([$organization_id, $new_category]);
        $final_category_id = $stmt->fetchColumn();
        error_log("New category ID: " . var_export($final_category_id, true));
    } elseif (!empty($category_id) && $category_id !== '') {
        error_log("Using existing category: " . $category_id);
        // User selected an existing category - verify it belongs to organization
        $stmt = $pdo->prepare("SELECT id FROM whsale_inventory_pro_categories WHERE id = ? AND organization_id = ?");
        $stmt->execute([$category_id, $organization_id]);
        if ($stmt->fetchColumn()) {
            $final_category_id = $category_id;
            error_log("Existing category verified: " . $final_category_id);
        } else {
            error_log("WARNING: Category $category_id not found for organization $organization_id");
        }
    }
    error_log("Final category ID: " . var_export($final_category_id, true));
    
    // Convert empty price to NULL for database
    $listed_price = ($listed_price !== '' && $listed_price !== null) ? (float)$listed_price : null;
    error_log("Final listed_price: " . var_export($listed_price, true));
    
    // Prepare final parameters for stored procedure
    $params = [
        $product_id, 
        $title, 
        $description, 
        $listed_price, 
        $is_active, 
        $final_category_id,
        $payment_link,
        $payment_type
    ];
    
    error_log("Calling stored procedure with parameters: " . print_r($params, true));
    
    // UPDATED: Call the updated stored procedure with payment fields
    $stmt = $pdo->prepare("CALL whsale_inventory_pro_update_storefront_product(?, ?, ?, ?, ?, ?, ?, ?)");
    $result = $stmt->execute($params);
    
    error_log("Stored procedure execution result: " . var_export($result, true));
    error_log("Affected rows: " . $stmt->rowCount());
    
    // Check for any errors from the procedure
    $errorInfo = $stmt->errorInfo();
    if ($errorInfo[0] !== '00000') {
        error_log("SQL Error from stored procedure: " . print_r($errorInfo, true));
        throw new Exception("Database error: " . $errorInfo[2]);
    }
    
    $stmt->closeCursor();
    
    // Let's also verify the update actually happened
    error_log("Verifying update was applied...");
    $verifyStmt = $pdo->prepare("SELECT title, description, listed_price, payment_link, payment_type, updated_at FROM whsale_inventory_pro_storefront_products WHERE id = ?");
    $verifyStmt->execute([$product_id]);
    $updatedProduct = $verifyStmt->fetch(PDO::FETCH_ASSOC);
    error_log("Product after update: " . print_r($updatedProduct, true));
    
    $pdo->commit();
    error_log("Transaction committed successfully");
    
    $_SESSION['success'] = "Product updated successfully.";
    error_log("=== STOREFRONT UPDATE DEBUG END (SUCCESS) ===");
    header("Location: " . BASE_URL . "storefront/manage");
    exit;
    
} catch (Exception $e) {
    $pdo->rollback();
    error_log("EXCEPTION CAUGHT: " . $e->getMessage());
    error_log("Exception trace: " . $e->getTraceAsString());
    error_log("=== STOREFRONT UPDATE DEBUG END (ERROR) ===");
    
    $_SESSION['error'] = "Update failed: " . $e->getMessage();
    header("Location: " . BASE_URL . "storefront/manage");
    exit;
}
?>