<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Require specific permission for publishing to storefront
AuthHelper::requirePermission('publish_to_storefront');

if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    http_response_code(405);
    echo "Method Not Allowed";
    exit;
}

$receiving_id = $_POST['receiving_id'] ?? null;
$title = trim($_POST['title'] ?? '');
$description = trim($_POST['description'] ?? '');
$product_price = trim($_POST['listed_price'] ?? '');
$category_id = $_POST['category_id'] ?? null;
$new_category = trim($_POST['new_category'] ?? '');
$organization_id = $_SESSION['organization_id'];

if (!$receiving_id || !$title || !$description) {
    http_response_code(400);
    echo "Missing required fields.";
    exit;
}

try {
    $pdo->beginTransaction();

    // UPDATED: Enhanced security - verify receiving log belongs to user's organization
    $stmt = $pdo->prepare("
        SELECT u.organization_id, r.category_id as receiving_category_id, c.category_name as receiving_category_name
        FROM whsale_inventory_pro_receiving_log r
        JOIN whsale_inventory_pro_users u ON r.created_by = u.id
        LEFT JOIN whsale_inventory_pro_categories c ON r.category_id = c.id
        WHERE r.id = ? AND r.organization_id = ?
    ");
    $stmt->execute([$receiving_id, $organization_id]);
    $orgRow = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$orgRow || $orgRow['organization_id'] != $organization_id) {
        throw new Exception("Receiving log not found or you don't have permission to publish it.");
    }

    // Handle category logic for storefront
    $final_category_id = null;
    
    if (!empty($new_category)) {
        // UPDATED: Enhanced security - verify user can create categories in their organization
        $stmt = $pdo->prepare("INSERT IGNORE INTO whsale_inventory_pro_categories (organization_id, category_name) VALUES (?, ?)");
        $stmt->execute([$organization_id, $new_category]);
        
        // Get the category ID (whether newly created or existing)
        $stmt = $pdo->prepare("SELECT id FROM whsale_inventory_pro_categories WHERE organization_id = ? AND category_name = ?");
        $stmt->execute([$organization_id, $new_category]);
        $final_category_id = $stmt->fetchColumn();
    } elseif (!empty($category_id) && $category_id !== '') {
        // UPDATED: Enhanced security - verify category belongs to user's organization
        $stmt = $pdo->prepare("SELECT id FROM whsale_inventory_pro_categories WHERE id = ? AND organization_id = ?");
        $stmt->execute([$category_id, $organization_id]);
        if ($stmt->fetchColumn()) {
            $final_category_id = $category_id;
        }
    }
    // If both are empty, $final_category_id remains null (no category for storefront)

    // Check if this receiving_id is already published to storefront
    $stmt = $pdo->prepare("
        SELECT sp.id FROM whsale_inventory_pro_storefront_products sp
        JOIN whsale_inventory_pro_receiving_log r ON sp.receiving_id = r.id
        WHERE sp.receiving_id = ? AND r.organization_id = ?
    ");
    $stmt->execute([$receiving_id, $organization_id]);
    if ($stmt->fetch()) {
        throw new Exception("This receiving log is already published to the storefront.");
    }

    // Insert into storefront table with the selected/created category
    $stmt = $pdo->prepare("
        INSERT INTO whsale_inventory_pro_storefront_products 
        (organization_id, receiving_id, category_id, title, description, listed_price, created_at)
        VALUES (?, ?, ?, ?, ?, ?, NOW())
    ");
    
    // Convert empty price to NULL for database
    $listed_price = ($product_price !== '' && $product_price !== null) ? $product_price : null;
    
    $stmt->execute([$organization_id, $receiving_id, $final_category_id, $title, $description, $listed_price]);

    $pdo->commit();

    // Redirect to storefront confirmation or management screen
    header("Location: " . BASE_URL . "storefront/confirmation?receiving_id=" . urlencode($receiving_id));
    exit;

} catch (Exception $e) {
    $pdo->rollback();
    error_log("Storefront publish error: " . $e->getMessage());
    http_response_code(500);
    echo "An error occurred: " . htmlspecialchars($e->getMessage());
    exit;
}
?>