<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';

$contact_success = isset($_GET['success']);
$contact_error = isset($_GET['error']);

if (!isset($receiving_id) || !is_numeric($receiving_id)) {
    http_response_code(400);
    echo "Invalid request: missing or invalid receiving ID.";
    exit;
}

if (!isset($organization_slug)) {
    http_response_code(400);
    echo "Invalid request: missing organization slug.";
    exit;
}

// Fetch logo path, display name, and color scheme
$orgDisplayName = '';
$logoPath = null;
$primaryColor = '#f66903';
$secondaryColor = '#ff9e49';
$navbarBgColor = '#ffffff';
$navbarTextColor = '#000000';
$bodyBgColor = '#f8f9fa';
$priceColor = '#198754';
$headingColor = '#212529';
$bodyTextColor = '#212529';
$mutedTextColor = '#6c757d';
$cardBgColor = '#ffffff';
$cardBorderColor = '#dee2e6';
$linkColor = '#0d6efd';

try {
    $stmt = $pdo->prepare("
        SELECT 
            b.logo_path, b.organization_display_name, b.primary_color, b.secondary_color, 
            b.navbar_bg_color, b.navbar_text_color, b.body_bg_color, b.price_color,
            b.heading_color, b.body_text_color, b.muted_text_color, b.card_bg_color, 
            b.card_border_color, b.link_color,
            o.organization_slug
        FROM whsale_inventory_pro_organizations o
        LEFT JOIN whsale_inventory_pro_org_branding b ON o.organization_id = b.organization_id
        WHERE o.organization_slug = ? 
        LIMIT 1
    ");
    $stmt->execute([$organization_slug]);
    $result = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($result) {
        // Use branding data if it exists, otherwise use defaults
        $logoPath = !empty($result['logo_path']) ? BASE_URL . 'public/uploads/logos/' . htmlspecialchars($result['logo_path']) : null;
        $orgDisplayName = $result['organization_display_name'] ?? ucfirst($result['organization_slug']);
        $primaryColor = $result['primary_color'] ?: $primaryColor;
        $secondaryColor = $result['secondary_color'] ?: $secondaryColor;
        $navbarBgColor = $result['navbar_bg_color'] ?: $navbarBgColor;
        $navbarTextColor = $result['navbar_text_color'] ?: $navbarTextColor;
        $bodyBgColor = $result['body_bg_color'] ?: $bodyBgColor;
        $priceColor = $result['price_color'] ?: $priceColor;
        $headingColor = $result['heading_color'] ?: $headingColor;
        $bodyTextColor = $result['body_text_color'] ?: $bodyTextColor;
        $mutedTextColor = $result['muted_text_color'] ?: $mutedTextColor;
        $cardBgColor = $result['card_bg_color'] ?: $cardBgColor;
        $cardBorderColor = $result['card_border_color'] ?: $cardBorderColor;
        $linkColor = $result['link_color'] ?: $linkColor;
    }

    // UPDATED: Fetch product data with payment information
    $stmt = $pdo->prepare("
        SELECT s.title, s.description, s.listed_price, s.created_at, s.payment_link, s.payment_type,
               r.vendor_name, r.po_number, r.delivery_date, r.notes,
               u.email AS seller_email, c.category_name
        FROM whsale_inventory_pro_storefront_products s
        JOIN whsale_inventory_pro_receiving_log r ON s.receiving_id = r.id
        JOIN whsale_inventory_pro_users u ON u.id = r.created_by
        LEFT JOIN whsale_inventory_pro_categories c ON s.category_id = c.id
        WHERE s.receiving_id = ? AND u.organization_slug = ? AND s.is_active = 1
        LIMIT 1
    ");
    $stmt->execute([$receiving_id, $organization_slug]);
    $product = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$product) {
        http_response_code(404);
        echo "Product not found.";
        exit;
    }

    $stmt = $pdo->prepare("
        SELECT file_path, caption
        FROM whsale_inventory_pro_receiving_photos
        WHERE receiving_id = ?
        ORDER BY uploaded_at DESC
    ");
    $stmt->execute([$receiving_id]);
    $photos = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (Exception $e) {
    http_response_code(500);
    echo "Error loading product details.";
    exit;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title><?= htmlspecialchars($product['title']) ?> | <?= htmlspecialchars($orgDisplayName ?: ucfirst($organization_slug)) ?> Storefront</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="description" content="<?= htmlspecialchars(substr($product['description'], 0, 160)) ?>...">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        body {
            background-color: <?= htmlspecialchars($bodyBgColor) ?>;
            color: <?= htmlspecialchars($bodyTextColor) ?>;
            padding-top: env(safe-area-inset-top, 60px);
        }

        .navbar-custom {
            background-color: <?= htmlspecialchars($navbarBgColor) ?> !important;
        }

        .navbar-custom .navbar-brand {
            color: <?= htmlspecialchars($navbarTextColor) ?> !important;
        }

        .org-logo {
            max-height: 80px;
            max-width: 250px;
            object-fit: contain;
            transition: all 0.3s ease;
        }

        /* Desktop and larger screens */
        @media (min-width: 992px) {
            .org-logo {
                max-height: 100px;
                max-width: 350px;
            }
        }

        /* Large desktop screens */
        @media (min-width: 1200px) {
            .org-logo {
                max-height: 120px;
                max-width: 400px;
            }
        }

        /* Tablet landscape and smaller desktop */
        @media (max-width: 991px) and (min-width: 768px) {
            .org-logo {
                max-height: 70px;
                max-width: 200px;
            }
        }

        /* Mobile landscape and tablet portrait */
        @media (max-width: 767px) and (min-width: 576px) {
            .org-logo {
                max-height: 60px;
                max-width: 180px;
            }
        }

        /* Small mobile devices */
        @media (max-width: 575px) {
            .org-logo {
                max-height: 50px;
                max-width: 150px;
            }
            
            /* Ensure navbar doesn't get too tall on small screens */
            .navbar {
                padding: 0.5rem 0;
            }
        }

        /* Very small screens */
        @media (max-width: 400px) {
            .org-logo {
                max-height: 40px;
                max-width: 120px;
            }
        }

        .product-title {
            color: <?= htmlspecialchars($headingColor) ?>;
            font-weight: 700;
            margin: 2rem 0 1rem 0;
        }

        .product-meta p {
            margin-bottom: 0.4rem;
        }

        .product-price {
            color: <?= htmlspecialchars($priceColor) ?> !important;
            font-weight: bold;
        }

        .photo-thumb {
            max-height: 180px;
            object-fit: cover;
            cursor: pointer;
            transition: all 0.3s ease;
        }

        .photo-tile {
            transition: transform 0.2s ease;
            height: 100%;
            background-color: <?= htmlspecialchars($cardBgColor) ?>;
            border: 1px solid <?= htmlspecialchars($cardBorderColor) ?>;
            cursor: pointer;
        }

        .photo-tile:hover {
            transform: scale(1.02);
        }

        .photo-tile:hover .photo-thumb {
            transform: scale(1.1);
        }

        .btn-primary {
            background-color: <?= htmlspecialchars($primaryColor) ?>;
            border-color: <?= htmlspecialchars($primaryColor) ?>;
        }

        .btn-primary:hover {
            background-color: <?= htmlspecialchars($secondaryColor) ?>;
            border-color: <?= htmlspecialchars($secondaryColor) ?>;
        }

        /* UPDATED: Buy Now button styling */
        .btn-buy-now {
            background: linear-gradient(135deg, <?= htmlspecialchars($primaryColor) ?>, <?= htmlspecialchars($primaryColor) ?>);
            border: none;
            color: white;
            font-weight: 600;
            font-size: 1.1rem;
            padding: 0.75rem 2rem;
            border-radius: 8px;
            box-shadow: 0 4px 15px rgba(0, 0, 0, 0.2);
            transition: all 0.3s ease;
            text-decoration: none;
            display: inline-flex;
            align-items: center;
            justify-content: center;
        }

        .btn-buy-now:hover {
            transform: translateY(-2px);
            box-shadow: 0 6px 20px rgba(0, 0, 0, 0.3);
            color: white;
            text-decoration: none;
        }

        .btn-buy-now:active {
            transform: translateY(0);
        }

        .btn-buy-now i {
            margin-right: 0.5rem;
            font-size: 1.2em;
        }

        .card {
            background-color: <?= htmlspecialchars($cardBgColor) ?>;
            border: 1px solid <?= htmlspecialchars($cardBorderColor) ?>;
            box-shadow: 0 0.125rem 0.25rem rgba(0, 0, 0, 0.075);
        }

        .card-title,
        .card-body h5,
        h1, h2, h3, h4, h5, h6 {
            color: <?= htmlspecialchars($headingColor) ?> !important;
        }

        .back-link {
            color: <?= htmlspecialchars($linkColor) ?>;
            text-decoration: none;
            font-weight: 500;
        }

        .back-link:hover {
            color: <?= htmlspecialchars($secondaryColor) ?>;
        }

        /* Product description and general text */
        .card-body p,
        .product-meta p {
            color: <?= htmlspecialchars($bodyTextColor) ?>;
        }

        /* Muted text like captions and dates */
        .text-muted,
        .small {
            color: <?= htmlspecialchars($mutedTextColor) ?> !important;
        }

        /* Form elements */
        .form-label {
            color: <?= htmlspecialchars($headingColor) ?>;
        }

        .form-control {
            border-color: <?= htmlspecialchars($cardBorderColor) ?>;
            color: <?= htmlspecialchars($bodyTextColor) ?>;
        }

        .form-control:focus {
            border-color: <?= htmlspecialchars($primaryColor) ?>;
            box-shadow: 0 0 0 0.2rem rgba(<?= 
                implode(', ', array_map(function($c) { 
                    return hexdec(substr($c, 1, 2)); 
                }, [substr($primaryColor, 1, 2), substr($primaryColor, 3, 2), substr($primaryColor, 5, 2)])) 
            ?>, 0.25);
        }

        /* Photo captions */
        .photo-tile p {
            color: <?= htmlspecialchars($mutedTextColor) ?>;
        }

        /* Alert styling */
        .alert-success {
            background-color: rgba(<?= 
                implode(', ', array_map(function($c) { 
                    return hexdec(substr($c, 1, 2)); 
                }, [substr($primaryColor, 1, 2), substr($primaryColor, 3, 2), substr($primaryColor, 5, 2)])) 
            ?>, 0.1);
            border-color: <?= htmlspecialchars($primaryColor) ?>;
            color: <?= htmlspecialchars($primaryColor) ?>;
        }

        .alert-danger {
            background-color: rgba(220, 53, 69, 0.1);
            border-color: #dc3545;
            color: #dc3545;
        }

        /* Links within content */
        a:not(.btn):not(.navbar-brand):not(.back-link):not(.btn-buy-now) {
            color: <?= htmlspecialchars($linkColor) ?>;
        }

        a:not(.btn):not(.navbar-brand):not(.back-link):not(.btn-buy-now):hover {
            color: <?= htmlspecialchars($secondaryColor) ?>;
        }

        /* Category badge styling */
        .category-badge {
            background-color: <?= htmlspecialchars($primaryColor) ?>;
            color: white;
        }

        /* Payment security notice */
        .payment-security {
            background-color: rgba(25, 135, 84, 0.1);
            border: 1px solid #198754;
            color: #198754;
            border-radius: 8px;
            padding: 0.75rem;
            margin-top: 1rem;
        }

        /* ENHANCED LIGHTBOX STYLES */
        .lightbox {
            display: none;
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background-color: rgba(0, 0, 0, 0.9);
            z-index: 9999;
            backdrop-filter: blur(5px);
        }

        .lightbox.active {
            display: flex;
            align-items: center;
            justify-content: center;
            animation: fadeIn 0.3s ease;
        }

        @keyframes fadeIn {
            from { opacity: 0; }
            to { opacity: 1; }
        }

        .lightbox-content {
            position: relative;
            max-width: 95vw;
            max-height: 95vh;
            display: flex;
            flex-direction: column;
            align-items: center;
        }

        .lightbox-image {
            max-width: 100%;
            max-height: 85vh;
            object-fit: contain;
            border-radius: 8px;
            box-shadow: 0 20px 60px rgba(0, 0, 0, 0.5);
            transition: all 0.3s ease;
        }

        .lightbox-caption {
            color: white;
            text-align: center;
            margin-top: 1rem;
            padding: 0.5rem 1rem;
            background-color: rgba(0, 0, 0, 0.7);
            border-radius: 20px;
            max-width: 80%;
            font-size: 1rem;
        }

        .lightbox-counter {
            position: absolute;
            top: 20px;
            right: 20px;
            color: white;
            background-color: rgba(0, 0, 0, 0.7);
            padding: 0.5rem 1rem;
            border-radius: 20px;
            font-size: 0.9rem;
            font-weight: 500;
        }

        .lightbox-close {
            position: absolute;
            top: 20px;
            left: 20px;
            color: white;
            background-color: rgba(0, 0, 0, 0.7);
            border: none;
            border-radius: 50%;
            width: 50px;
            height: 50px;
            font-size: 1.5rem;
            cursor: pointer;
            transition: all 0.3s ease;
            display: flex;
            align-items: center;
            justify-content: center;
        }

        .lightbox-close:hover {
            background-color: rgba(255, 255, 255, 0.2);
            transform: scale(1.1);
        }

        .lightbox-nav {
            position: absolute;
            top: 50%;
            transform: translateY(-50%);
            color: white;
            background-color: rgba(0, 0, 0, 0.7);
            border: none;
            border-radius: 50%;
            width: 60px;
            height: 60px;
            font-size: 1.5rem;
            cursor: pointer;
            transition: all 0.3s ease;
            display: flex;
            align-items: center;
            justify-content: center;
        }

        .lightbox-nav:hover {
            background-color: rgba(255, 255, 255, 0.2);
            transform: translateY(-50%) scale(1.1);
        }

        .lightbox-nav.prev {
            left: 20px;
        }

        .lightbox-nav.next {
            right: 20px;
        }

        .lightbox-nav:disabled {
            opacity: 0.3;
            cursor: not-allowed;
        }

        .lightbox-nav:disabled:hover {
            background-color: rgba(0, 0, 0, 0.7);
            transform: translateY(-50%) scale(1);
        }

        /* Thumbnail indicator */
        .lightbox-thumbnails {
            position: absolute;
            bottom: 20px;
            left: 50%;
            transform: translateX(-50%);
            display: flex;
            gap: 0.5rem;
            max-width: 90%;
            overflow-x: auto;
            padding: 0.5rem;
            background-color: rgba(0, 0, 0, 0.5);
            border-radius: 25px;
            scrollbar-width: none;
            -ms-overflow-style: none;
        }

        .lightbox-thumbnails::-webkit-scrollbar {
            display: none;
        }

        .lightbox-thumb {
            width: 60px;
            height: 40px;
            object-fit: cover;
            border-radius: 4px;
            cursor: pointer;
            opacity: 0.6;
            transition: all 0.3s ease;
            border: 2px solid transparent;
        }

        .lightbox-thumb.active {
            opacity: 1;
            border-color: white;
            transform: scale(1.1);
        }

        .lightbox-thumb:hover {
            opacity: 0.9;
        }

        /* Mobile optimizations */
        @media (max-width: 768px) {
            .lightbox-nav {
                width: 50px;
                height: 50px;
                font-size: 1.2rem;
            }
            
            .lightbox-close {
                width: 40px;
                height: 40px;
                font-size: 1.2rem;
            }
            
            .lightbox-counter {
                top: 10px;
                right: 10px;
                font-size: 0.8rem;
                padding: 0.3rem 0.7rem;
            }
            
            .lightbox-thumbnails {
                bottom: 10px;
                max-width: 95%;
            }
            
            .lightbox-thumb {
                width: 50px;
                height: 35px;
            }
            
            .lightbox-caption {
                font-size: 0.9rem;
                max-width: 90%;
            }

            .btn-buy-now {
                width: 100%;
                margin-bottom: 1rem;
            }
        }

        @media (max-width: 576px) {
            .lightbox-nav.prev {
                left: 10px;
            }
            
            .lightbox-nav.next {
                right: 10px;
            }
            
            .lightbox-close {
                top: 10px;
                left: 10px;
            }
        }

        @media (max-width: 767.98px) {
            .product-title {
                font-size: 1.75rem;
                margin: 1.5rem 0 1rem 0;
            }

            .photo-thumb {
                max-height: 150px;
            }

            .card-body {
                padding: 1rem;
            }

            .photo-tile {
                padding: 0.5rem;
            }
        }

        @media (max-width: 576px) {
            .photo-thumb {
                max-height: 120px;
            }

            .card-title {
                font-size: 1.2rem;
            }

            .form-label {
                font-size: 0.95rem;
            }

            .product-title {
                font-size: 1.5rem;
            }
        }
    </style>
</head>
<body>

<nav class="navbar navbar-expand-lg navbar-custom shadow-sm sticky-top">
  <div class="container d-flex align-items-center">
    <a class="navbar-brand fw-bold d-flex align-items-center" href="<?= BASE_URL ?>storefront/<?= urlencode($organization_slug) ?>">
        <?php if ($logoPath): ?>
            <img src="<?= $logoPath ?>" alt="Store Logo" class="org-logo">
        <?php else: ?>
            <span class="fw-bold"><?= htmlspecialchars($orgDisplayName ?: ucfirst($organization_slug)) ?></span>
        <?php endif; ?>
    </a>
  </div>
</nav>

<div class="container mt-3">
    <a href="<?= BASE_URL ?>storefront/<?= urlencode($organization_slug) ?>" class="back-link">
        ← Back to Products
    </a>
</div>

<div class="container">
    <div class="text-center">
        <h2 class="product-title"><?= htmlspecialchars($product['title']) ?></h2>
        <?php if (!empty($product['category_name'])): ?>
            <span class="badge category-badge fs-6 mb-3">
                <i class="fas fa-tag me-1"></i><?= htmlspecialchars($product['category_name']) ?>
            </span>
        <?php endif; ?>
    </div>
</div>

<!-- Description Card -->
<div class="container mb-4">
    <div class="card shadow-sm mx-auto" style="max-width: 900px;">
        <div class="card-body">
            <h5>Description</h5>
            <p><?= nl2br(htmlspecialchars($product['description'])) ?></p>
        </div>
    </div>
</div>

<!-- Photos Section -->
<?php if (!empty($photos)): ?>
    <div class="container mb-4">
        <div class="mx-auto" style="max-width: 900px;">
            <h5 class="mb-3">
                <i class="fas fa-images me-2"></i>Photos (<?= count($photos) ?>)
                <small class="text-muted ms-2">Click to view full size</small>
            </h5>
            <div class="row g-3">
                <?php foreach ($photos as $index => $photo): ?>
                    <div class="col-6 col-sm-4 col-md-3">
                        <div class="photo-tile border rounded p-2 shadow-sm text-center h-100" 
                             onclick="openLightbox(<?= $index ?>)"
                             data-index="<?= $index ?>"
                             data-src="<?= BASE_URL ?>public/uploads/receiving/<?= htmlspecialchars($photo['file_path']) ?>"
                             data-caption="<?= htmlspecialchars($photo['caption'] ?? '') ?>">
                            <img src="<?= BASE_URL ?>public/uploads/receiving/<?= htmlspecialchars($photo['file_path']) ?>" 
                                 class="img-fluid rounded photo-thumb mb-2" 
                                 alt="Product Photo <?= $index + 1 ?>"
                                 loading="lazy">
                            <?php if (!empty($photo['caption'])): ?>
                                <p class="small text-muted mb-0"><?= htmlspecialchars($photo['caption']) ?></p>
                            <?php endif; ?>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>
    </div>
<?php endif; ?>

<!-- Product Info Card -->
<div class="container mb-4">
    <div class="card shadow-sm mx-auto" style="max-width: 900px;">
        <div class="card-body product-meta">
            <h5>Product Information</h5>
            <div class="row">
                <div class="col-md-6">
                    <p><strong>Listed Price:</strong> 
                        <span class="product-price">
                            <?= $product['listed_price'] ? '$' . number_format($product['listed_price'], 2) : '—' ?>
                        </span>
                    </p>
                    <p><strong>Posted:</strong> <?= date('M d, Y', strtotime($product['created_at'])) ?></p>
                </div>
                <div class="col-md-6">
                    <p><strong>Category:</strong> 
                        <?php if (!empty($product['category_name'])): ?>
                            <span class="badge bg-light text-dark">
                                <?= htmlspecialchars($product['category_name']) ?>
                            </span>
                        <?php else: ?>
                            <span class="text-muted">Uncategorized</span>
                        <?php endif; ?>
                    </p>
                </div>
            </div>

            <!-- UPDATED: Buy Now Section -->
            <?php if (!empty($product['payment_link'])): ?>
                <hr class="my-4">
                <div class="text-center">
                    <h6 class="mb-3">
                        <i class="fas fa-shopping-cart me-2"></i>Purchase Online
                    </h6>
                    <a href="<?= htmlspecialchars($product['payment_link']) ?>" 
                       class="btn-buy-now" 
                       target="_blank" 
                       rel="noopener noreferrer"
                       onclick="trackPaymentClick('<?= htmlspecialchars($product['payment_type'] ?? 'unknown') ?>')">
                        <i class="fas fa-credit-card"></i>
                        Buy Now <?= $product['listed_price'] ? '$' . number_format($product['listed_price'], 2) : '' ?>
                    </a>
                    
                    <div class="payment-security">
                        <i class="fas fa-shield-alt me-2"></i>
                        <strong>Secure Payment:</strong> This link will take you to a secure 
                        <?= ucfirst($product['payment_type'] ?? 'payment') ?> checkout page.
                    </div>
                </div>
            <?php endif; ?>
        </div>
    </div>
</div>

<!-- Contact Seller Card -->
<div class="container mb-5">
    <div class="card shadow-sm mx-auto" style="max-width: 900px;">
        <div class="card-body">
            <h5 class="card-title mb-3">
                <i class="fas fa-envelope me-2"></i>
                <?= !empty($product['payment_link']) ? 'Questions? Contact Seller' : 'Contact Seller' ?>
            </h5>

            <?php if ($contact_success): ?>
                <div class="alert alert-success">
                    <i class="fas fa-check-circle me-2"></i>Message sent successfully! We'll get back to you soon.
                </div>
            <?php elseif ($contact_error): ?>
                <div class="alert alert-danger">
                    <i class="fas fa-exclamation-triangle me-2"></i>There was an error sending your message. Please try again.
                </div>
            <?php endif; ?>

            <form method="POST" action="<?= BASE_URL ?>storefront/contact" class="mt-3">
                <input type="hidden" name="organization_slug" value="<?= htmlspecialchars($organization_slug) ?>">
                <input type="hidden" name="receiving_id" value="<?= htmlspecialchars($receiving_id) ?>">

                <div class="mb-4">
                    <label for="email" class="form-label">
                        <i class="fas fa-at me-1"></i>Your Email
                    </label>
                    <input type="email" name="email" id="email" class="form-control" required 
                           placeholder="your.email@example.com">
                </div>
                <div class="mb-3">
                    <label for="message" class="form-label">
                        <i class="fas fa-comment me-1"></i>Message
                    </label>
                    <textarea name="message" id="message" rows="4" class="form-control" required 
                              placeholder="Hi, I'm interested in this product. Please provide more details..."></textarea>
                </div>
                <button type="submit" class="btn btn-primary w-100">
                    <i class="fas fa-paper-plane me-2"></i>Send Message
                </button>
            </form>

        </div>
    </div>
</div>

<!-- Enhanced Lightbox -->
<div id="lightbox" class="lightbox">
    <div class="lightbox-content">
        <button class="lightbox-close" onclick="closeLightbox()" aria-label="Close">×</button>
        <div class="lightbox-counter">
            <span id="lightbox-current">1</span> / <span id="lightbox-total"><?= count($photos) ?></span>
        </div>
        
        <img id="lightbox-image" class="lightbox-image" src="" alt="Product Photo">
        
        <button class="lightbox-nav prev" onclick="prevImage()" aria-label="Previous image">‹</button>
        <button class="lightbox-nav next" onclick="nextImage()" aria-label="Next image">›</button>
        
        <div id="lightbox-caption" class="lightbox-caption"></div>
        
        <!-- Thumbnail navigation -->
        <div class="lightbox-thumbnails" id="lightbox-thumbnails">
            <?php foreach ($photos as $index => $photo): ?>
                <img src="<?= BASE_URL ?>public/uploads/receiving/<?= htmlspecialchars($photo['file_path']) ?>" 
                     class="lightbox-thumb" 
                     onclick="goToImage(<?= $index ?>)"
                     data-index="<?= $index ?>"
                     alt="Thumbnail <?= $index + 1 ?>">
            <?php endforeach; ?>
        </div>
    </div>
</div>

<script>
// Enhanced Lightbox functionality
let currentImageIndex = 0;
const photos = <?= json_encode(array_map(function($photo, $index) use ($photos) {
    return [
        'src' => BASE_URL . 'public/uploads/receiving/' . $photo['file_path'],
        'caption' => $photo['caption'] ?? '',
        'index' => $index
    ];
}, $photos, array_keys($photos))) ?>;

function openLightbox(index) {
    currentImageIndex = index;
    updateLightboxImage();
    document.getElementById('lightbox').classList.add('active');
    document.body.style.overflow = 'hidden'; // Prevent background scrolling
    
    // Add keyboard event listener
    document.addEventListener('keydown', handleKeyDown);
}

function closeLightbox() {
    document.getElementById('lightbox').classList.remove('active');
    document.body.style.overflow = ''; // Restore scrolling
    
    // Remove keyboard event listener
    document.removeEventListener('keydown', handleKeyDown);
}

function nextImage() {
    if (currentImageIndex < photos.length - 1) {
        currentImageIndex++;
        updateLightboxImage();
    }
}

function prevImage() {
    if (currentImageIndex > 0) {
        currentImageIndex--;
        updateLightboxImage();
    }
}

function goToImage(index) {
    currentImageIndex = index;
    updateLightboxImage();
}

function updateLightboxImage() {
    const photo = photos[currentImageIndex];
    const lightboxImage = document.getElementById('lightbox-image');
    const lightboxCaption = document.getElementById('lightbox-caption');
    const lightboxCurrent = document.getElementById('lightbox-current');
    
    // Update image
    lightboxImage.src = photo.src;
    lightboxImage.alt = `Product Photo ${currentImageIndex + 1}`;
    
    // Update caption
    lightboxCaption.textContent = photo.caption;
    lightboxCaption.style.display = photo.caption ? 'block' : 'none';
    
    // Update counter
    lightboxCurrent.textContent = currentImageIndex + 1;
    
    // Update navigation buttons
    const prevBtn = document.querySelector('.lightbox-nav.prev');
    const nextBtn = document.querySelector('.lightbox-nav.next');
    
    prevBtn.disabled = currentImageIndex === 0;
    nextBtn.disabled = currentImageIndex === photos.length - 1;
    
    // Update thumbnail indicators
    document.querySelectorAll('.lightbox-thumb').forEach((thumb, index) => {
        thumb.classList.toggle('active', index === currentImageIndex);
    });
    
    // Scroll active thumbnail into view
    const activeThumbnail = document.querySelector('.lightbox-thumb.active');
    if (activeThumbnail) {
        activeThumbnail.scrollIntoView({
            behavior: 'smooth',
            block: 'nearest',
            inline: 'center'
        });
    }
}

function handleKeyDown(event) {
    switch(event.key) {
        case 'Escape':
            closeLightbox();
            break;
        case 'ArrowLeft':
            prevImage();
            break;
        case 'ArrowRight':
            nextImage();
            break;
    }
}

// Close lightbox when clicking outside the image
document.getElementById('lightbox').addEventListener('click', function(event) {
    if (event.target === this) {
        closeLightbox();
    }
});

// Prevent image dragging
document.addEventListener('dragstart', function(event) {
    if (event.target.tagName === 'IMG') {
        event.preventDefault();
    }
});

// Touch/swipe support for mobile
let touchStartX = 0;
let touchEndX = 0;

document.getElementById('lightbox').addEventListener('touchstart', function(event) {
    touchStartX = event.changedTouches[0].screenX;
});

document.getElementById('lightbox').addEventListener('touchend', function(event) {
    touchEndX = event.changedTouches[0].screenX;
    handleSwipe();
});

function handleSwipe() {
    const swipeThreshold = 50;
    const difference = touchStartX - touchEndX;
    
    if (Math.abs(difference) > swipeThreshold) {
        if (difference > 0) {
            // Swiped left - next image
            nextImage();
        } else {
            // Swiped right - previous image
            prevImage();
        }
    }
}

// UPDATED: Track payment link clicks for analytics
function trackPaymentClick(paymentType) {
    // You can add analytics tracking here
    console.log(`Payment link clicked: ${paymentType}`);
    
    // Optional: Send analytics to your backend
    // fetch('/api/track-payment-click', {
    //     method: 'POST',
    //     headers: { 'Content-Type': 'application/json' },
    //     body: JSON.stringify({
    //         receiving_id: '<?= $receiving_id ?>',
    //         payment_type: paymentType,
    //         timestamp: new Date().toISOString()
    //     })
    // });
}

// Preload adjacent images for smooth navigation
function preloadAdjacentImages() {
    const preloadImages = [];
    
    // Preload previous image
    if (currentImageIndex > 0) {
        const prevImg = new Image();
        prevImg.src = photos[currentImageIndex - 1].src;
        preloadImages.push(prevImg);
    }
    
    // Preload next image
    if (currentImageIndex < photos.length - 1) {
        const nextImg = new Image();
        nextImg.src = photos[currentImageIndex + 1].src;
        preloadImages.push(nextImg);
    }
}

// Call preload when opening lightbox
document.addEventListener('DOMContentLoaded', function() {
    // Initialize thumbnail active state
    if (photos.length > 0) {
        document.querySelector('.lightbox-thumb[data-index="0"]')?.classList.add('active');
    }
});
</script>

</body>
</html>